#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataDataservicePropertyBusinesspropertyModifyModel(object):

    def __init__(self):
        self._biz_owner_id = None
        self._business_profile_category_id = None
        self._business_property_id = None
        self._creator_id = None
        self._data_owner_id = None
        self._data_type = None
        self._enum_id = None
        self._personality_info = None
        self._proc_type = None
        self._property_desc = None
        self._propery_name = None
        self._quality_owner_id = None

    @property
    def biz_owner_id(self):
        return self._biz_owner_id

    @biz_owner_id.setter
    def biz_owner_id(self, value):
        self._biz_owner_id = value
    @property
    def business_profile_category_id(self):
        return self._business_profile_category_id

    @business_profile_category_id.setter
    def business_profile_category_id(self, value):
        self._business_profile_category_id = value
    @property
    def business_property_id(self):
        return self._business_property_id

    @business_property_id.setter
    def business_property_id(self, value):
        self._business_property_id = value
    @property
    def creator_id(self):
        return self._creator_id

    @creator_id.setter
    def creator_id(self, value):
        self._creator_id = value
    @property
    def data_owner_id(self):
        return self._data_owner_id

    @data_owner_id.setter
    def data_owner_id(self, value):
        self._data_owner_id = value
    @property
    def data_type(self):
        return self._data_type

    @data_type.setter
    def data_type(self, value):
        self._data_type = value
    @property
    def enum_id(self):
        return self._enum_id

    @enum_id.setter
    def enum_id(self, value):
        self._enum_id = value
    @property
    def personality_info(self):
        return self._personality_info

    @personality_info.setter
    def personality_info(self, value):
        if isinstance(value, list):
            self._personality_info = list()
            for i in value:
                self._personality_info.append(i)
    @property
    def proc_type(self):
        return self._proc_type

    @proc_type.setter
    def proc_type(self, value):
        self._proc_type = value
    @property
    def property_desc(self):
        return self._property_desc

    @property_desc.setter
    def property_desc(self, value):
        self._property_desc = value
    @property
    def propery_name(self):
        return self._propery_name

    @propery_name.setter
    def propery_name(self, value):
        self._propery_name = value
    @property
    def quality_owner_id(self):
        return self._quality_owner_id

    @quality_owner_id.setter
    def quality_owner_id(self, value):
        self._quality_owner_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_owner_id:
            if hasattr(self.biz_owner_id, 'to_alipay_dict'):
                params['biz_owner_id'] = self.biz_owner_id.to_alipay_dict()
            else:
                params['biz_owner_id'] = self.biz_owner_id
        if self.business_profile_category_id:
            if hasattr(self.business_profile_category_id, 'to_alipay_dict'):
                params['business_profile_category_id'] = self.business_profile_category_id.to_alipay_dict()
            else:
                params['business_profile_category_id'] = self.business_profile_category_id
        if self.business_property_id:
            if hasattr(self.business_property_id, 'to_alipay_dict'):
                params['business_property_id'] = self.business_property_id.to_alipay_dict()
            else:
                params['business_property_id'] = self.business_property_id
        if self.creator_id:
            if hasattr(self.creator_id, 'to_alipay_dict'):
                params['creator_id'] = self.creator_id.to_alipay_dict()
            else:
                params['creator_id'] = self.creator_id
        if self.data_owner_id:
            if hasattr(self.data_owner_id, 'to_alipay_dict'):
                params['data_owner_id'] = self.data_owner_id.to_alipay_dict()
            else:
                params['data_owner_id'] = self.data_owner_id
        if self.data_type:
            if hasattr(self.data_type, 'to_alipay_dict'):
                params['data_type'] = self.data_type.to_alipay_dict()
            else:
                params['data_type'] = self.data_type
        if self.enum_id:
            if hasattr(self.enum_id, 'to_alipay_dict'):
                params['enum_id'] = self.enum_id.to_alipay_dict()
            else:
                params['enum_id'] = self.enum_id
        if self.personality_info:
            if isinstance(self.personality_info, list):
                for i in range(0, len(self.personality_info)):
                    element = self.personality_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.personality_info[i] = element.to_alipay_dict()
            if hasattr(self.personality_info, 'to_alipay_dict'):
                params['personality_info'] = self.personality_info.to_alipay_dict()
            else:
                params['personality_info'] = self.personality_info
        if self.proc_type:
            if hasattr(self.proc_type, 'to_alipay_dict'):
                params['proc_type'] = self.proc_type.to_alipay_dict()
            else:
                params['proc_type'] = self.proc_type
        if self.property_desc:
            if hasattr(self.property_desc, 'to_alipay_dict'):
                params['property_desc'] = self.property_desc.to_alipay_dict()
            else:
                params['property_desc'] = self.property_desc
        if self.propery_name:
            if hasattr(self.propery_name, 'to_alipay_dict'):
                params['propery_name'] = self.propery_name.to_alipay_dict()
            else:
                params['propery_name'] = self.propery_name
        if self.quality_owner_id:
            if hasattr(self.quality_owner_id, 'to_alipay_dict'):
                params['quality_owner_id'] = self.quality_owner_id.to_alipay_dict()
            else:
                params['quality_owner_id'] = self.quality_owner_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataDataservicePropertyBusinesspropertyModifyModel()
        if 'biz_owner_id' in d:
            o.biz_owner_id = d['biz_owner_id']
        if 'business_profile_category_id' in d:
            o.business_profile_category_id = d['business_profile_category_id']
        if 'business_property_id' in d:
            o.business_property_id = d['business_property_id']
        if 'creator_id' in d:
            o.creator_id = d['creator_id']
        if 'data_owner_id' in d:
            o.data_owner_id = d['data_owner_id']
        if 'data_type' in d:
            o.data_type = d['data_type']
        if 'enum_id' in d:
            o.enum_id = d['enum_id']
        if 'personality_info' in d:
            o.personality_info = d['personality_info']
        if 'proc_type' in d:
            o.proc_type = d['proc_type']
        if 'property_desc' in d:
            o.property_desc = d['property_desc']
        if 'propery_name' in d:
            o.propery_name = d['propery_name']
        if 'quality_owner_id' in d:
            o.quality_owner_id = d['quality_owner_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayPayAppSmartwearStatusQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayPayAppSmartwearStatusQueryResponse, self).__init__()
        self._device_model = None
        self._product_type = None
        self._security_solution = None
        self._status = None

    @property
    def device_model(self):
        return self._device_model

    @device_model.setter
    def device_model(self, value):
        self._device_model = value
    @property
    def product_type(self):
        return self._product_type

    @product_type.setter
    def product_type(self, value):
        self._product_type = value
    @property
    def security_solution(self):
        return self._security_solution

    @security_solution.setter
    def security_solution(self, value):
        self._security_solution = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayPayAppSmartwearStatusQueryResponse, self).parse_response_content(response_content)
        if 'device_model' in response:
            self.device_model = response['device_model']
        if 'product_type' in response:
            self.product_type = response['product_type']
        if 'security_solution' in response:
            self.security_solution = response['security_solution']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayInsSceneApplicationApplyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsSceneApplicationApplyResponse, self).__init__()
        self._application_no = None
        self._operation_id = None
        self._out_biz_no = None
        self._policy_detail_url_4_mobile = None
        self._policy_detail_url_4_pc = None
        self._policy_no = None
        self._trade_no = None
        self._trade_type = None
        self._underwrite_reject_reason = None

    @property
    def application_no(self):
        return self._application_no

    @application_no.setter
    def application_no(self, value):
        self._application_no = value
    @property
    def operation_id(self):
        return self._operation_id

    @operation_id.setter
    def operation_id(self, value):
        self._operation_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def policy_detail_url_4_mobile(self):
        return self._policy_detail_url_4_mobile

    @policy_detail_url_4_mobile.setter
    def policy_detail_url_4_mobile(self, value):
        self._policy_detail_url_4_mobile = value
    @property
    def policy_detail_url_4_pc(self):
        return self._policy_detail_url_4_pc

    @policy_detail_url_4_pc.setter
    def policy_detail_url_4_pc(self, value):
        self._policy_detail_url_4_pc = value
    @property
    def policy_no(self):
        return self._policy_no

    @policy_no.setter
    def policy_no(self, value):
        self._policy_no = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def trade_type(self):
        return self._trade_type

    @trade_type.setter
    def trade_type(self, value):
        self._trade_type = value
    @property
    def underwrite_reject_reason(self):
        return self._underwrite_reject_reason

    @underwrite_reject_reason.setter
    def underwrite_reject_reason(self, value):
        self._underwrite_reject_reason = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsSceneApplicationApplyResponse, self).parse_response_content(response_content)
        if 'application_no' in response:
            self.application_no = response['application_no']
        if 'operation_id' in response:
            self.operation_id = response['operation_id']
        if 'out_biz_no' in response:
            self.out_biz_no = response['out_biz_no']
        if 'policy_detail_url_4_mobile' in response:
            self.policy_detail_url_4_mobile = response['policy_detail_url_4_mobile']
        if 'policy_detail_url_4_pc' in response:
            self.policy_detail_url_4_pc = response['policy_detail_url_4_pc']
        if 'policy_no' in response:
            self.policy_no = response['policy_no']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']
        if 'trade_type' in response:
            self.trade_type = response['trade_type']
        if 'underwrite_reject_reason' in response:
            self.underwrite_reject_reason = response['underwrite_reject_reason']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingCampaignPromotionactivityCustomerReceiveModel(object):

    def __init__(self):
        self._activity_id = None
        self._apdid = None
        self._client_ip = None
        self._merchant_pid = None
        self._out_biz_no = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def apdid(self):
        return self._apdid

    @apdid.setter
    def apdid(self, value):
        self._apdid = value
    @property
    def client_ip(self):
        return self._client_ip

    @client_ip.setter
    def client_ip(self, value):
        self._client_ip = value
    @property
    def merchant_pid(self):
        return self._merchant_pid

    @merchant_pid.setter
    def merchant_pid(self, value):
        self._merchant_pid = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.apdid:
            if hasattr(self.apdid, 'to_alipay_dict'):
                params['apdid'] = self.apdid.to_alipay_dict()
            else:
                params['apdid'] = self.apdid
        if self.client_ip:
            if hasattr(self.client_ip, 'to_alipay_dict'):
                params['client_ip'] = self.client_ip.to_alipay_dict()
            else:
                params['client_ip'] = self.client_ip
        if self.merchant_pid:
            if hasattr(self.merchant_pid, 'to_alipay_dict'):
                params['merchant_pid'] = self.merchant_pid.to_alipay_dict()
            else:
                params['merchant_pid'] = self.merchant_pid
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCampaignPromotionactivityCustomerReceiveModel()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'apdid' in d:
            o.apdid = d['apdid']
        if 'client_ip' in d:
            o.client_ip = d['client_ip']
        if 'merchant_pid' in d:
            o.merchant_pid = d['merchant_pid']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserCertifyIdentifyVerifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserCertifyIdentifyVerifyResponse, self).__init__()
        self._biz_code_status = None

    @property
    def biz_code_status(self):
        return self._biz_code_status

    @biz_code_status.setter
    def biz_code_status(self, value):
        self._biz_code_status = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserCertifyIdentifyVerifyResponse, self).parse_response_content(response_content)
        if 'biz_code_status' in response:
            self.biz_code_status = response['biz_code_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.VoucherLiteInfo import VoucherLiteInfo


class AlipayMarketingVoucherListQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingVoucherListQueryResponse, self).__init__()
        self._vouchers = None

    @property
    def vouchers(self):
        return self._vouchers

    @vouchers.setter
    def vouchers(self, value):
        if isinstance(value, list):
            self._vouchers = list()
            for i in value:
                if isinstance(i, VoucherLiteInfo):
                    self._vouchers.append(i)
                else:
                    self._vouchers.append(VoucherLiteInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingVoucherListQueryResponse, self).parse_response_content(response_content)
        if 'vouchers' in response:
            self.vouchers = response['vouchers']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySecurityDataDatabusSendModel(object):

    def __init__(self):
        self._security_content = None
        self._security_sign = None

    @property
    def security_content(self):
        return self._security_content

    @security_content.setter
    def security_content(self, value):
        self._security_content = value
    @property
    def security_sign(self):
        return self._security_sign

    @security_sign.setter
    def security_sign(self, value):
        self._security_sign = value


    def to_alipay_dict(self):
        params = dict()
        if self.security_content:
            if hasattr(self.security_content, 'to_alipay_dict'):
                params['security_content'] = self.security_content.to_alipay_dict()
            else:
                params['security_content'] = self.security_content
        if self.security_sign:
            if hasattr(self.security_sign, 'to_alipay_dict'):
                params['security_sign'] = self.security_sign.to_alipay_dict()
            else:
                params['security_sign'] = self.security_sign
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityDataDatabusSendModel()
        if 'security_content' in d:
            o.security_content = d['security_content']
        if 'security_sign' in d:
            o.security_sign = d['security_sign']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.KbExtItemInfo import KbExtItemInfo


class KoubeiItemExtitemInfoQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiItemExtitemInfoQueryResponse, self).__init__()
        self._kb_ext_item_info = None

    @property
    def kb_ext_item_info(self):
        return self._kb_ext_item_info

    @kb_ext_item_info.setter
    def kb_ext_item_info(self, value):
        if isinstance(value, KbExtItemInfo):
            self._kb_ext_item_info = value
        else:
            self._kb_ext_item_info = KbExtItemInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(KoubeiItemExtitemInfoQueryResponse, self).parse_response_content(response_content)
        if 'kb_ext_item_info' in response:
            self.kb_ext_item_info = response['kb_ext_item_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class UpdateCodeRequest(object):

    def __init__(self):
        self._action = None
        self._biz_id = None
        self._code_token = None
        self._context_data = None

    @property
    def action(self):
        return self._action

    @action.setter
    def action(self, value):
        self._action = value
    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def code_token(self):
        return self._code_token

    @code_token.setter
    def code_token(self, value):
        self._code_token = value
    @property
    def context_data(self):
        return self._context_data

    @context_data.setter
    def context_data(self, value):
        self._context_data = value


    def to_alipay_dict(self):
        params = dict()
        if self.action:
            if hasattr(self.action, 'to_alipay_dict'):
                params['action'] = self.action.to_alipay_dict()
            else:
                params['action'] = self.action
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.code_token:
            if hasattr(self.code_token, 'to_alipay_dict'):
                params['code_token'] = self.code_token.to_alipay_dict()
            else:
                params['code_token'] = self.code_token
        if self.context_data:
            if hasattr(self.context_data, 'to_alipay_dict'):
                params['context_data'] = self.context_data.to_alipay_dict()
            else:
                params['context_data'] = self.context_data
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = UpdateCodeRequest()
        if 'action' in d:
            o.action = d['action']
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'code_token' in d:
            o.code_token = d['code_token']
        if 'context_data' in d:
            o.context_data = d['context_data']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AlipayUserDetail import AlipayUserDetail


class AlipayUserGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserGetResponse, self).__init__()
        self._alipay_user_detail = None

    @property
    def alipay_user_detail(self):
        return self._alipay_user_detail

    @alipay_user_detail.setter
    def alipay_user_detail(self, value):
        if isinstance(value, AlipayUserDetail):
            self._alipay_user_detail = value
        else:
            self._alipay_user_detail = AlipayUserDetail.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayUserGetResponse, self).parse_response_content(response_content)
        if 'alipay_user_detail' in response:
            self.alipay_user_detail = response['alipay_user_detail']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.IntentQueryResponse import IntentQueryResponse


class AlipayIserviceIotIntentQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayIserviceIotIntentQueryResponse, self).__init__()
        self._iot_response = None

    @property
    def iot_response(self):
        return self._iot_response

    @iot_response.setter
    def iot_response(self, value):
        if isinstance(value, IntentQueryResponse):
            self._iot_response = value
        else:
            self._iot_response = IntentQueryResponse.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayIserviceIotIntentQueryResponse, self).parse_response_content(response_content)
        if 'iot_response' in response:
            self.iot_response = response['iot_response']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.IotDeliveryAgencyMerchantInfo import IotDeliveryAgencyMerchantInfo
from alipay.aop.api.domain.IotDeliveryBaseInfo import IotDeliveryBaseInfo
from alipay.aop.api.domain.IotDeliveryPlayConfig import IotDeliveryPlayConfig


class AlipayMarketingActivityIotdeliveryCreateModel(object):

    def __init__(self):
        self._belong_merchant_info = None
        self._delivery_base_info = None
        self._delivery_booth_code = None
        self._delivery_play_config = None
        self._out_biz_no = None

    @property
    def belong_merchant_info(self):
        return self._belong_merchant_info

    @belong_merchant_info.setter
    def belong_merchant_info(self, value):
        if isinstance(value, IotDeliveryAgencyMerchantInfo):
            self._belong_merchant_info = value
        else:
            self._belong_merchant_info = IotDeliveryAgencyMerchantInfo.from_alipay_dict(value)
    @property
    def delivery_base_info(self):
        return self._delivery_base_info

    @delivery_base_info.setter
    def delivery_base_info(self, value):
        if isinstance(value, IotDeliveryBaseInfo):
            self._delivery_base_info = value
        else:
            self._delivery_base_info = IotDeliveryBaseInfo.from_alipay_dict(value)
    @property
    def delivery_booth_code(self):
        return self._delivery_booth_code

    @delivery_booth_code.setter
    def delivery_booth_code(self, value):
        self._delivery_booth_code = value
    @property
    def delivery_play_config(self):
        return self._delivery_play_config

    @delivery_play_config.setter
    def delivery_play_config(self, value):
        if isinstance(value, IotDeliveryPlayConfig):
            self._delivery_play_config = value
        else:
            self._delivery_play_config = IotDeliveryPlayConfig.from_alipay_dict(value)
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.belong_merchant_info:
            if hasattr(self.belong_merchant_info, 'to_alipay_dict'):
                params['belong_merchant_info'] = self.belong_merchant_info.to_alipay_dict()
            else:
                params['belong_merchant_info'] = self.belong_merchant_info
        if self.delivery_base_info:
            if hasattr(self.delivery_base_info, 'to_alipay_dict'):
                params['delivery_base_info'] = self.delivery_base_info.to_alipay_dict()
            else:
                params['delivery_base_info'] = self.delivery_base_info
        if self.delivery_booth_code:
            if hasattr(self.delivery_booth_code, 'to_alipay_dict'):
                params['delivery_booth_code'] = self.delivery_booth_code.to_alipay_dict()
            else:
                params['delivery_booth_code'] = self.delivery_booth_code
        if self.delivery_play_config:
            if hasattr(self.delivery_play_config, 'to_alipay_dict'):
                params['delivery_play_config'] = self.delivery_play_config.to_alipay_dict()
            else:
                params['delivery_play_config'] = self.delivery_play_config
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingActivityIotdeliveryCreateModel()
        if 'belong_merchant_info' in d:
            o.belong_merchant_info = d['belong_merchant_info']
        if 'delivery_base_info' in d:
            o.delivery_base_info = d['delivery_base_info']
        if 'delivery_booth_code' in d:
            o.delivery_booth_code = d['delivery_booth_code']
        if 'delivery_play_config' in d:
            o.delivery_play_config = d['delivery_play_config']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BFActivityOpenApiInfo import BFActivityOpenApiInfo


class BFActivityOpenApiResult(object):

    def __init__(self):
        self._activity_infos = None

    @property
    def activity_infos(self):
        return self._activity_infos

    @activity_infos.setter
    def activity_infos(self, value):
        if isinstance(value, list):
            self._activity_infos = list()
            for i in value:
                if isinstance(i, BFActivityOpenApiInfo):
                    self._activity_infos.append(i)
                else:
                    self._activity_infos.append(BFActivityOpenApiInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.activity_infos:
            if isinstance(self.activity_infos, list):
                for i in range(0, len(self.activity_infos)):
                    element = self.activity_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.activity_infos[i] = element.to_alipay_dict()
            if hasattr(self.activity_infos, 'to_alipay_dict'):
                params['activity_infos'] = self.activity_infos.to_alipay_dict()
            else:
                params['activity_infos'] = self.activity_infos
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BFActivityOpenApiResult()
        if 'activity_infos' in d:
            o.activity_infos = d['activity_infos']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundTransAacollectBatchCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundTransAacollectBatchCreateResponse, self).__init__()
        self._batch_no = None
        self._batch_token = None

    @property
    def batch_no(self):
        return self._batch_no

    @batch_no.setter
    def batch_no(self, value):
        self._batch_no = value
    @property
    def batch_token(self):
        return self._batch_token

    @batch_token.setter
    def batch_token(self, value):
        self._batch_token = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundTransAacollectBatchCreateResponse, self).parse_response_content(response_content)
        if 'batch_no' in response:
            self.batch_no = response['batch_no']
        if 'batch_token' in response:
            self.batch_token = response['batch_token']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MarketingAuthorizedData import MarketingAuthorizedData
from alipay.aop.api.domain.MarketingPartner import MarketingPartner


class MarketingPartnerShip(object):

    def __init__(self):
        self._authorized_data = None
        self._create_time = None
        self._partner = None
        self._status = None
        self._stop_time = None

    @property
    def authorized_data(self):
        return self._authorized_data

    @authorized_data.setter
    def authorized_data(self, value):
        if isinstance(value, MarketingAuthorizedData):
            self._authorized_data = value
        else:
            self._authorized_data = MarketingAuthorizedData.from_alipay_dict(value)
    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, value):
        self._create_time = value
    @property
    def partner(self):
        return self._partner

    @partner.setter
    def partner(self, value):
        if isinstance(value, MarketingPartner):
            self._partner = value
        else:
            self._partner = MarketingPartner.from_alipay_dict(value)
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def stop_time(self):
        return self._stop_time

    @stop_time.setter
    def stop_time(self, value):
        self._stop_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.authorized_data:
            if hasattr(self.authorized_data, 'to_alipay_dict'):
                params['authorized_data'] = self.authorized_data.to_alipay_dict()
            else:
                params['authorized_data'] = self.authorized_data
        if self.create_time:
            if hasattr(self.create_time, 'to_alipay_dict'):
                params['create_time'] = self.create_time.to_alipay_dict()
            else:
                params['create_time'] = self.create_time
        if self.partner:
            if hasattr(self.partner, 'to_alipay_dict'):
                params['partner'] = self.partner.to_alipay_dict()
            else:
                params['partner'] = self.partner
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.stop_time:
            if hasattr(self.stop_time, 'to_alipay_dict'):
                params['stop_time'] = self.stop_time.to_alipay_dict()
            else:
                params['stop_time'] = self.stop_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MarketingPartnerShip()
        if 'authorized_data' in d:
            o.authorized_data = d['authorized_data']
        if 'create_time' in d:
            o.create_time = d['create_time']
        if 'partner' in d:
            o.partner = d['partner']
        if 'status' in d:
            o.status = d['status']
        if 'stop_time' in d:
            o.stop_time = d['stop_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenIotvspUserwithimageCreateModel(object):

    def __init__(self):
        self._cert_name = None
        self._cert_no = None
        self._cert_type = None
        self._component_out_id = None
        self._ext = None
        self._image = None
        self._isv_pid = None
        self._label_out_no = None
        self._org_out_id = None
        self._phone = None
        self._vid = None

    @property
    def cert_name(self):
        return self._cert_name

    @cert_name.setter
    def cert_name(self, value):
        self._cert_name = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def component_out_id(self):
        return self._component_out_id

    @component_out_id.setter
    def component_out_id(self, value):
        self._component_out_id = value
    @property
    def ext(self):
        return self._ext

    @ext.setter
    def ext(self, value):
        self._ext = value
    @property
    def image(self):
        return self._image

    @image.setter
    def image(self, value):
        self._image = value
    @property
    def isv_pid(self):
        return self._isv_pid

    @isv_pid.setter
    def isv_pid(self, value):
        self._isv_pid = value
    @property
    def label_out_no(self):
        return self._label_out_no

    @label_out_no.setter
    def label_out_no(self, value):
        self._label_out_no = value
    @property
    def org_out_id(self):
        return self._org_out_id

    @org_out_id.setter
    def org_out_id(self, value):
        self._org_out_id = value
    @property
    def phone(self):
        return self._phone

    @phone.setter
    def phone(self, value):
        self._phone = value
    @property
    def vid(self):
        return self._vid

    @vid.setter
    def vid(self, value):
        self._vid = value


    def to_alipay_dict(self):
        params = dict()
        if self.cert_name:
            if hasattr(self.cert_name, 'to_alipay_dict'):
                params['cert_name'] = self.cert_name.to_alipay_dict()
            else:
                params['cert_name'] = self.cert_name
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.component_out_id:
            if hasattr(self.component_out_id, 'to_alipay_dict'):
                params['component_out_id'] = self.component_out_id.to_alipay_dict()
            else:
                params['component_out_id'] = self.component_out_id
        if self.ext:
            if hasattr(self.ext, 'to_alipay_dict'):
                params['ext'] = self.ext.to_alipay_dict()
            else:
                params['ext'] = self.ext
        if self.image:
            if hasattr(self.image, 'to_alipay_dict'):
                params['image'] = self.image.to_alipay_dict()
            else:
                params['image'] = self.image
        if self.isv_pid:
            if hasattr(self.isv_pid, 'to_alipay_dict'):
                params['isv_pid'] = self.isv_pid.to_alipay_dict()
            else:
                params['isv_pid'] = self.isv_pid
        if self.label_out_no:
            if hasattr(self.label_out_no, 'to_alipay_dict'):
                params['label_out_no'] = self.label_out_no.to_alipay_dict()
            else:
                params['label_out_no'] = self.label_out_no
        if self.org_out_id:
            if hasattr(self.org_out_id, 'to_alipay_dict'):
                params['org_out_id'] = self.org_out_id.to_alipay_dict()
            else:
                params['org_out_id'] = self.org_out_id
        if self.phone:
            if hasattr(self.phone, 'to_alipay_dict'):
                params['phone'] = self.phone.to_alipay_dict()
            else:
                params['phone'] = self.phone
        if self.vid:
            if hasattr(self.vid, 'to_alipay_dict'):
                params['vid'] = self.vid.to_alipay_dict()
            else:
                params['vid'] = self.vid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenIotvspUserwithimageCreateModel()
        if 'cert_name' in d:
            o.cert_name = d['cert_name']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'component_out_id' in d:
            o.component_out_id = d['component_out_id']
        if 'ext' in d:
            o.ext = d['ext']
        if 'image' in d:
            o.image = d['image']
        if 'isv_pid' in d:
            o.isv_pid = d['isv_pid']
        if 'label_out_no' in d:
            o.label_out_no = d['label_out_no']
        if 'org_out_id' in d:
            o.org_out_id = d['org_out_id']
        if 'phone' in d:
            o.phone = d['phone']
        if 'vid' in d:
            o.vid = d['vid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayAccountExrateAdviceAcceptResponse(AlipayResponse):

    def __init__(self):
        super(AlipayAccountExrateAdviceAcceptResponse, self).__init__()
        self._client_id = None
        self._contra_amount = None
        self._contra_ccy = None
        self._deal_ref = None
        self._dealt_rate = None
        self._duplicate = None
        self._messag_id = None
        self._msg_type = None
        self._requested_rate_status = None
        self._side = None
        self._transaction_amount = None
        self._transaction_ccy = None
        self._value_date = None

    @property
    def client_id(self):
        return self._client_id

    @client_id.setter
    def client_id(self, value):
        self._client_id = value
    @property
    def contra_amount(self):
        return self._contra_amount

    @contra_amount.setter
    def contra_amount(self, value):
        self._contra_amount = value
    @property
    def contra_ccy(self):
        return self._contra_ccy

    @contra_ccy.setter
    def contra_ccy(self, value):
        self._contra_ccy = value
    @property
    def deal_ref(self):
        return self._deal_ref

    @deal_ref.setter
    def deal_ref(self, value):
        self._deal_ref = value
    @property
    def dealt_rate(self):
        return self._dealt_rate

    @dealt_rate.setter
    def dealt_rate(self, value):
        self._dealt_rate = value
    @property
    def duplicate(self):
        return self._duplicate

    @duplicate.setter
    def duplicate(self, value):
        self._duplicate = value
    @property
    def messag_id(self):
        return self._messag_id

    @messag_id.setter
    def messag_id(self, value):
        self._messag_id = value
    @property
    def msg_type(self):
        return self._msg_type

    @msg_type.setter
    def msg_type(self, value):
        self._msg_type = value
    @property
    def requested_rate_status(self):
        return self._requested_rate_status

    @requested_rate_status.setter
    def requested_rate_status(self, value):
        self._requested_rate_status = value
    @property
    def side(self):
        return self._side

    @side.setter
    def side(self, value):
        self._side = value
    @property
    def transaction_amount(self):
        return self._transaction_amount

    @transaction_amount.setter
    def transaction_amount(self, value):
        self._transaction_amount = value
    @property
    def transaction_ccy(self):
        return self._transaction_ccy

    @transaction_ccy.setter
    def transaction_ccy(self, value):
        self._transaction_ccy = value
    @property
    def value_date(self):
        return self._value_date

    @value_date.setter
    def value_date(self, value):
        self._value_date = value

    def parse_response_content(self, response_content):
        response = super(AlipayAccountExrateAdviceAcceptResponse, self).parse_response_content(response_content)
        if 'client_id' in response:
            self.client_id = response['client_id']
        if 'contra_amount' in response:
            self.contra_amount = response['contra_amount']
        if 'contra_ccy' in response:
            self.contra_ccy = response['contra_ccy']
        if 'deal_ref' in response:
            self.deal_ref = response['deal_ref']
        if 'dealt_rate' in response:
            self.dealt_rate = response['dealt_rate']
        if 'duplicate' in response:
            self.duplicate = response['duplicate']
        if 'messag_id' in response:
            self.messag_id = response['messag_id']
        if 'msg_type' in response:
            self.msg_type = response['msg_type']
        if 'requested_rate_status' in response:
            self.requested_rate_status = response['requested_rate_status']
        if 'side' in response:
            self.side = response['side']
        if 'transaction_amount' in response:
            self.transaction_amount = response['transaction_amount']
        if 'transaction_ccy' in response:
            self.transaction_ccy = response['transaction_ccy']
        if 'value_date' in response:
            self.value_date = response['value_date']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayAssetPointPointprodBudgetlibAddModel(object):

    def __init__(self):
        self._amount = None
        self._budget_code = None
        self._contract_pid = None
        self._memo = None
        self._operator = None
        self._order_no = None
        self._point_lib_id = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def budget_code(self):
        return self._budget_code

    @budget_code.setter
    def budget_code(self, value):
        self._budget_code = value
    @property
    def contract_pid(self):
        return self._contract_pid

    @contract_pid.setter
    def contract_pid(self, value):
        self._contract_pid = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def point_lib_id(self):
        return self._point_lib_id

    @point_lib_id.setter
    def point_lib_id(self, value):
        self._point_lib_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.budget_code:
            if hasattr(self.budget_code, 'to_alipay_dict'):
                params['budget_code'] = self.budget_code.to_alipay_dict()
            else:
                params['budget_code'] = self.budget_code
        if self.contract_pid:
            if hasattr(self.contract_pid, 'to_alipay_dict'):
                params['contract_pid'] = self.contract_pid.to_alipay_dict()
            else:
                params['contract_pid'] = self.contract_pid
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = self.order_no.to_alipay_dict()
            else:
                params['order_no'] = self.order_no
        if self.point_lib_id:
            if hasattr(self.point_lib_id, 'to_alipay_dict'):
                params['point_lib_id'] = self.point_lib_id.to_alipay_dict()
            else:
                params['point_lib_id'] = self.point_lib_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayAssetPointPointprodBudgetlibAddModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'budget_code' in d:
            o.budget_code = d['budget_code']
        if 'contract_pid' in d:
            o.contract_pid = d['contract_pid']
        if 'memo' in d:
            o.memo = d['memo']
        if 'operator' in d:
            o.operator = d['operator']
        if 'order_no' in d:
            o.order_no = d['order_no']
        if 'point_lib_id' in d:
            o.point_lib_id = d['point_lib_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TestResult import TestResult
from alipay.aop.api.domain.TestResult import TestResult


class IndicatorData(object):

    def __init__(self):
        self._absolute = None
        self._id = None
        self._name = None
        self._relative = None

    @property
    def absolute(self):
        return self._absolute

    @absolute.setter
    def absolute(self, value):
        if isinstance(value, TestResult):
            self._absolute = value
        else:
            self._absolute = TestResult.from_alipay_dict(value)
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def relative(self):
        return self._relative

    @relative.setter
    def relative(self, value):
        if isinstance(value, TestResult):
            self._relative = value
        else:
            self._relative = TestResult.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.absolute:
            if hasattr(self.absolute, 'to_alipay_dict'):
                params['absolute'] = self.absolute.to_alipay_dict()
            else:
                params['absolute'] = self.absolute
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.relative:
            if hasattr(self.relative, 'to_alipay_dict'):
                params['relative'] = self.relative.to_alipay_dict()
            else:
                params['relative'] = self.relative
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = IndicatorData()
        if 'absolute' in d:
            o.absolute = d['absolute']
        if 'id' in d:
            o.id = d['id']
        if 'name' in d:
            o.name = d['name']
        if 'relative' in d:
            o.relative = d['relative']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class WarehouseVO(object):

    def __init__(self):
        self._address = None
        self._area_code = None
        self._area_name = None
        self._biz_status = None
        self._cainiao_code = None
        self._city_code = None
        self._city_name = None
        self._contact = None
        self._lat = None
        self._lon = None
        self._owner_id = None
        self._phone = None
        self._province_code = None
        self._province_name = None
        self._shop_id = None
        self._warehouse_code = None
        self._warehouse_name = None
        self._warehouse_type = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def area_code(self):
        return self._area_code

    @area_code.setter
    def area_code(self, value):
        self._area_code = value
    @property
    def area_name(self):
        return self._area_name

    @area_name.setter
    def area_name(self, value):
        self._area_name = value
    @property
    def biz_status(self):
        return self._biz_status

    @biz_status.setter
    def biz_status(self, value):
        self._biz_status = value
    @property
    def cainiao_code(self):
        return self._cainiao_code

    @cainiao_code.setter
    def cainiao_code(self, value):
        self._cainiao_code = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def city_name(self):
        return self._city_name

    @city_name.setter
    def city_name(self, value):
        self._city_name = value
    @property
    def contact(self):
        return self._contact

    @contact.setter
    def contact(self, value):
        self._contact = value
    @property
    def lat(self):
        return self._lat

    @lat.setter
    def lat(self, value):
        self._lat = value
    @property
    def lon(self):
        return self._lon

    @lon.setter
    def lon(self, value):
        self._lon = value
    @property
    def owner_id(self):
        return self._owner_id

    @owner_id.setter
    def owner_id(self, value):
        self._owner_id = value
    @property
    def phone(self):
        return self._phone

    @phone.setter
    def phone(self, value):
        self._phone = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def province_name(self):
        return self._province_name

    @province_name.setter
    def province_name(self, value):
        self._province_name = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def warehouse_code(self):
        return self._warehouse_code

    @warehouse_code.setter
    def warehouse_code(self, value):
        self._warehouse_code = value
    @property
    def warehouse_name(self):
        return self._warehouse_name

    @warehouse_name.setter
    def warehouse_name(self, value):
        self._warehouse_name = value
    @property
    def warehouse_type(self):
        return self._warehouse_type

    @warehouse_type.setter
    def warehouse_type(self, value):
        self._warehouse_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.area_code:
            if hasattr(self.area_code, 'to_alipay_dict'):
                params['area_code'] = self.area_code.to_alipay_dict()
            else:
                params['area_code'] = self.area_code
        if self.area_name:
            if hasattr(self.area_name, 'to_alipay_dict'):
                params['area_name'] = self.area_name.to_alipay_dict()
            else:
                params['area_name'] = self.area_name
        if self.biz_status:
            if hasattr(self.biz_status, 'to_alipay_dict'):
                params['biz_status'] = self.biz_status.to_alipay_dict()
            else:
                params['biz_status'] = self.biz_status
        if self.cainiao_code:
            if hasattr(self.cainiao_code, 'to_alipay_dict'):
                params['cainiao_code'] = self.cainiao_code.to_alipay_dict()
            else:
                params['cainiao_code'] = self.cainiao_code
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.city_name:
            if hasattr(self.city_name, 'to_alipay_dict'):
                params['city_name'] = self.city_name.to_alipay_dict()
            else:
                params['city_name'] = self.city_name
        if self.contact:
            if hasattr(self.contact, 'to_alipay_dict'):
                params['contact'] = self.contact.to_alipay_dict()
            else:
                params['contact'] = self.contact
        if self.lat:
            if hasattr(self.lat, 'to_alipay_dict'):
                params['lat'] = self.lat.to_alipay_dict()
            else:
                params['lat'] = self.lat
        if self.lon:
            if hasattr(self.lon, 'to_alipay_dict'):
                params['lon'] = self.lon.to_alipay_dict()
            else:
                params['lon'] = self.lon
        if self.owner_id:
            if hasattr(self.owner_id, 'to_alipay_dict'):
                params['owner_id'] = self.owner_id.to_alipay_dict()
            else:
                params['owner_id'] = self.owner_id
        if self.phone:
            if hasattr(self.phone, 'to_alipay_dict'):
                params['phone'] = self.phone.to_alipay_dict()
            else:
                params['phone'] = self.phone
        if self.province_code:
            if hasattr(self.province_code, 'to_alipay_dict'):
                params['province_code'] = self.province_code.to_alipay_dict()
            else:
                params['province_code'] = self.province_code
        if self.province_name:
            if hasattr(self.province_name, 'to_alipay_dict'):
                params['province_name'] = self.province_name.to_alipay_dict()
            else:
                params['province_name'] = self.province_name
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.warehouse_code:
            if hasattr(self.warehouse_code, 'to_alipay_dict'):
                params['warehouse_code'] = self.warehouse_code.to_alipay_dict()
            else:
                params['warehouse_code'] = self.warehouse_code
        if self.warehouse_name:
            if hasattr(self.warehouse_name, 'to_alipay_dict'):
                params['warehouse_name'] = self.warehouse_name.to_alipay_dict()
            else:
                params['warehouse_name'] = self.warehouse_name
        if self.warehouse_type:
            if hasattr(self.warehouse_type, 'to_alipay_dict'):
                params['warehouse_type'] = self.warehouse_type.to_alipay_dict()
            else:
                params['warehouse_type'] = self.warehouse_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = WarehouseVO()
        if 'address' in d:
            o.address = d['address']
        if 'area_code' in d:
            o.area_code = d['area_code']
        if 'area_name' in d:
            o.area_name = d['area_name']
        if 'biz_status' in d:
            o.biz_status = d['biz_status']
        if 'cainiao_code' in d:
            o.cainiao_code = d['cainiao_code']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'city_name' in d:
            o.city_name = d['city_name']
        if 'contact' in d:
            o.contact = d['contact']
        if 'lat' in d:
            o.lat = d['lat']
        if 'lon' in d:
            o.lon = d['lon']
        if 'owner_id' in d:
            o.owner_id = d['owner_id']
        if 'phone' in d:
            o.phone = d['phone']
        if 'province_code' in d:
            o.province_code = d['province_code']
        if 'province_name' in d:
            o.province_name = d['province_name']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'warehouse_code' in d:
            o.warehouse_code = d['warehouse_code']
        if 'warehouse_name' in d:
            o.warehouse_name = d['warehouse_name']
        if 'warehouse_type' in d:
            o.warehouse_type = d['warehouse_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class VoucherBalanceRechargeInfo(object):

    def __init__(self):
        self._amount = None
        self._logon_id = None
        self._partner_id = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def logon_id(self):
        return self._logon_id

    @logon_id.setter
    def logon_id(self, value):
        self._logon_id = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.logon_id:
            if hasattr(self.logon_id, 'to_alipay_dict'):
                params['logon_id'] = self.logon_id.to_alipay_dict()
            else:
                params['logon_id'] = self.logon_id
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherBalanceRechargeInfo()
        if 'amount' in d:
            o.amount = d['amount']
        if 'logon_id' in d:
            o.logon_id = d['logon_id']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SignRecordLogVO(object):

    def __init__(self):
        self._s_version = None
        self._status = None
        self._trans_date = None

    @property
    def s_version(self):
        return self._s_version

    @s_version.setter
    def s_version(self, value):
        self._s_version = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def trans_date(self):
        return self._trans_date

    @trans_date.setter
    def trans_date(self, value):
        self._trans_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.s_version:
            if hasattr(self.s_version, 'to_alipay_dict'):
                params['s_version'] = self.s_version.to_alipay_dict()
            else:
                params['s_version'] = self.s_version
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.trans_date:
            if hasattr(self.trans_date, 'to_alipay_dict'):
                params['trans_date'] = self.trans_date.to_alipay_dict()
            else:
                params['trans_date'] = self.trans_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SignRecordLogVO()
        if 's_version' in d:
            o.s_version = d['s_version']
        if 'status' in d:
            o.status = d['status']
        if 'trans_date' in d:
            o.trans_date = d['trans_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TipsDelivery(object):

    def __init__(self):
        self._delivery_content = None
        self._delivery_id = None
        self._delivery_name = None
        self._end_time = None
        self._fail_reason = None
        self._match_type = None
        self._match_url = None
        self._start_time = None
        self._status = None

    @property
    def delivery_content(self):
        return self._delivery_content

    @delivery_content.setter
    def delivery_content(self, value):
        self._delivery_content = value
    @property
    def delivery_id(self):
        return self._delivery_id

    @delivery_id.setter
    def delivery_id(self, value):
        self._delivery_id = value
    @property
    def delivery_name(self):
        return self._delivery_name

    @delivery_name.setter
    def delivery_name(self, value):
        self._delivery_name = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def fail_reason(self):
        return self._fail_reason

    @fail_reason.setter
    def fail_reason(self, value):
        self._fail_reason = value
    @property
    def match_type(self):
        return self._match_type

    @match_type.setter
    def match_type(self, value):
        self._match_type = value
    @property
    def match_url(self):
        return self._match_url

    @match_url.setter
    def match_url(self, value):
        self._match_url = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.delivery_content:
            if hasattr(self.delivery_content, 'to_alipay_dict'):
                params['delivery_content'] = self.delivery_content.to_alipay_dict()
            else:
                params['delivery_content'] = self.delivery_content
        if self.delivery_id:
            if hasattr(self.delivery_id, 'to_alipay_dict'):
                params['delivery_id'] = self.delivery_id.to_alipay_dict()
            else:
                params['delivery_id'] = self.delivery_id
        if self.delivery_name:
            if hasattr(self.delivery_name, 'to_alipay_dict'):
                params['delivery_name'] = self.delivery_name.to_alipay_dict()
            else:
                params['delivery_name'] = self.delivery_name
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.fail_reason:
            if hasattr(self.fail_reason, 'to_alipay_dict'):
                params['fail_reason'] = self.fail_reason.to_alipay_dict()
            else:
                params['fail_reason'] = self.fail_reason
        if self.match_type:
            if hasattr(self.match_type, 'to_alipay_dict'):
                params['match_type'] = self.match_type.to_alipay_dict()
            else:
                params['match_type'] = self.match_type
        if self.match_url:
            if hasattr(self.match_url, 'to_alipay_dict'):
                params['match_url'] = self.match_url.to_alipay_dict()
            else:
                params['match_url'] = self.match_url
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TipsDelivery()
        if 'delivery_content' in d:
            o.delivery_content = d['delivery_content']
        if 'delivery_id' in d:
            o.delivery_id = d['delivery_id']
        if 'delivery_name' in d:
            o.delivery_name = d['delivery_name']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'fail_reason' in d:
            o.fail_reason = d['fail_reason']
        if 'match_type' in d:
            o.match_type = d['match_type']
        if 'match_url' in d:
            o.match_url = d['match_url']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ArInvoiceLineOpenApiResponse import ArInvoiceLineOpenApiResponse
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi


class ArRelInvoiceOpenApiResponse(object):

    def __init__(self):
        self._ar_invoice_lines = None
        self._buyer_address = None
        self._buyer_bank_account = None
        self._buyer_bank_name = None
        self._buyer_invoice_title = None
        self._buyer_tax_no = None
        self._buyer_telephone = None
        self._can_link = None
        self._creator = None
        self._drawer = None
        self._elc_invoice_url = None
        self._gmt_create = None
        self._gmt_modified = None
        self._inst_id = None
        self._invoice_amt = None
        self._invoice_channel = None
        self._invoice_code = None
        self._invoice_date = None
        self._invoice_id = None
        self._invoice_material = None
        self._invoice_no = None
        self._invoice_note = None
        self._invoice_status = None
        self._invoice_type = None
        self._ip_id = None
        self._ip_role_id = None
        self._last_moder = None
        self._linked_amt = None
        self._mail_status = None
        self._memo = None
        self._no_bill_invoice_flag = None
        self._online = None
        self._payee = None
        self._recent_mail_id = None
        self._red = None
        self._red_amt = None
        self._reviewer = None
        self._seller_address = None
        self._seller_bank_account = None
        self._seller_bank_name = None
        self._seller_company_name = None
        self._seller_tax_no = None
        self._seller_telephone = None
        self._tnt_inst_id = None

    @property
    def ar_invoice_lines(self):
        return self._ar_invoice_lines

    @ar_invoice_lines.setter
    def ar_invoice_lines(self, value):
        if isinstance(value, ArInvoiceLineOpenApiResponse):
            self._ar_invoice_lines = value
        else:
            self._ar_invoice_lines = ArInvoiceLineOpenApiResponse.from_alipay_dict(value)
    @property
    def buyer_address(self):
        return self._buyer_address

    @buyer_address.setter
    def buyer_address(self, value):
        self._buyer_address = value
    @property
    def buyer_bank_account(self):
        return self._buyer_bank_account

    @buyer_bank_account.setter
    def buyer_bank_account(self, value):
        self._buyer_bank_account = value
    @property
    def buyer_bank_name(self):
        return self._buyer_bank_name

    @buyer_bank_name.setter
    def buyer_bank_name(self, value):
        self._buyer_bank_name = value
    @property
    def buyer_invoice_title(self):
        return self._buyer_invoice_title

    @buyer_invoice_title.setter
    def buyer_invoice_title(self, value):
        self._buyer_invoice_title = value
    @property
    def buyer_tax_no(self):
        return self._buyer_tax_no

    @buyer_tax_no.setter
    def buyer_tax_no(self, value):
        self._buyer_tax_no = value
    @property
    def buyer_telephone(self):
        return self._buyer_telephone

    @buyer_telephone.setter
    def buyer_telephone(self, value):
        self._buyer_telephone = value
    @property
    def can_link(self):
        return self._can_link

    @can_link.setter
    def can_link(self, value):
        self._can_link = value
    @property
    def creator(self):
        return self._creator

    @creator.setter
    def creator(self, value):
        self._creator = value
    @property
    def drawer(self):
        return self._drawer

    @drawer.setter
    def drawer(self, value):
        self._drawer = value
    @property
    def elc_invoice_url(self):
        return self._elc_invoice_url

    @elc_invoice_url.setter
    def elc_invoice_url(self, value):
        self._elc_invoice_url = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def invoice_amt(self):
        return self._invoice_amt

    @invoice_amt.setter
    def invoice_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._invoice_amt = value
        else:
            self._invoice_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def invoice_channel(self):
        return self._invoice_channel

    @invoice_channel.setter
    def invoice_channel(self, value):
        self._invoice_channel = value
    @property
    def invoice_code(self):
        return self._invoice_code

    @invoice_code.setter
    def invoice_code(self, value):
        self._invoice_code = value
    @property
    def invoice_date(self):
        return self._invoice_date

    @invoice_date.setter
    def invoice_date(self, value):
        self._invoice_date = value
    @property
    def invoice_id(self):
        return self._invoice_id

    @invoice_id.setter
    def invoice_id(self, value):
        self._invoice_id = value
    @property
    def invoice_material(self):
        return self._invoice_material

    @invoice_material.setter
    def invoice_material(self, value):
        self._invoice_material = value
    @property
    def invoice_no(self):
        return self._invoice_no

    @invoice_no.setter
    def invoice_no(self, value):
        self._invoice_no = value
    @property
    def invoice_note(self):
        return self._invoice_note

    @invoice_note.setter
    def invoice_note(self, value):
        self._invoice_note = value
    @property
    def invoice_status(self):
        return self._invoice_status

    @invoice_status.setter
    def invoice_status(self, value):
        self._invoice_status = value
    @property
    def invoice_type(self):
        return self._invoice_type

    @invoice_type.setter
    def invoice_type(self, value):
        self._invoice_type = value
    @property
    def ip_id(self):
        return self._ip_id

    @ip_id.setter
    def ip_id(self, value):
        self._ip_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def last_moder(self):
        return self._last_moder

    @last_moder.setter
    def last_moder(self, value):
        self._last_moder = value
    @property
    def linked_amt(self):
        return self._linked_amt

    @linked_amt.setter
    def linked_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._linked_amt = value
        else:
            self._linked_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def mail_status(self):
        return self._mail_status

    @mail_status.setter
    def mail_status(self, value):
        self._mail_status = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def no_bill_invoice_flag(self):
        return self._no_bill_invoice_flag

    @no_bill_invoice_flag.setter
    def no_bill_invoice_flag(self, value):
        self._no_bill_invoice_flag = value
    @property
    def online(self):
        return self._online

    @online.setter
    def online(self, value):
        self._online = value
    @property
    def payee(self):
        return self._payee

    @payee.setter
    def payee(self, value):
        self._payee = value
    @property
    def recent_mail_id(self):
        return self._recent_mail_id

    @recent_mail_id.setter
    def recent_mail_id(self, value):
        self._recent_mail_id = value
    @property
    def red(self):
        return self._red

    @red.setter
    def red(self, value):
        self._red = value
    @property
    def red_amt(self):
        return self._red_amt

    @red_amt.setter
    def red_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._red_amt = value
        else:
            self._red_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def reviewer(self):
        return self._reviewer

    @reviewer.setter
    def reviewer(self, value):
        self._reviewer = value
    @property
    def seller_address(self):
        return self._seller_address

    @seller_address.setter
    def seller_address(self, value):
        self._seller_address = value
    @property
    def seller_bank_account(self):
        return self._seller_bank_account

    @seller_bank_account.setter
    def seller_bank_account(self, value):
        self._seller_bank_account = value
    @property
    def seller_bank_name(self):
        return self._seller_bank_name

    @seller_bank_name.setter
    def seller_bank_name(self, value):
        self._seller_bank_name = value
    @property
    def seller_company_name(self):
        return self._seller_company_name

    @seller_company_name.setter
    def seller_company_name(self, value):
        self._seller_company_name = value
    @property
    def seller_tax_no(self):
        return self._seller_tax_no

    @seller_tax_no.setter
    def seller_tax_no(self, value):
        self._seller_tax_no = value
    @property
    def seller_telephone(self):
        return self._seller_telephone

    @seller_telephone.setter
    def seller_telephone(self, value):
        self._seller_telephone = value
    @property
    def tnt_inst_id(self):
        return self._tnt_inst_id

    @tnt_inst_id.setter
    def tnt_inst_id(self, value):
        self._tnt_inst_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.ar_invoice_lines:
            if hasattr(self.ar_invoice_lines, 'to_alipay_dict'):
                params['ar_invoice_lines'] = self.ar_invoice_lines.to_alipay_dict()
            else:
                params['ar_invoice_lines'] = self.ar_invoice_lines
        if self.buyer_address:
            if hasattr(self.buyer_address, 'to_alipay_dict'):
                params['buyer_address'] = self.buyer_address.to_alipay_dict()
            else:
                params['buyer_address'] = self.buyer_address
        if self.buyer_bank_account:
            if hasattr(self.buyer_bank_account, 'to_alipay_dict'):
                params['buyer_bank_account'] = self.buyer_bank_account.to_alipay_dict()
            else:
                params['buyer_bank_account'] = self.buyer_bank_account
        if self.buyer_bank_name:
            if hasattr(self.buyer_bank_name, 'to_alipay_dict'):
                params['buyer_bank_name'] = self.buyer_bank_name.to_alipay_dict()
            else:
                params['buyer_bank_name'] = self.buyer_bank_name
        if self.buyer_invoice_title:
            if hasattr(self.buyer_invoice_title, 'to_alipay_dict'):
                params['buyer_invoice_title'] = self.buyer_invoice_title.to_alipay_dict()
            else:
                params['buyer_invoice_title'] = self.buyer_invoice_title
        if self.buyer_tax_no:
            if hasattr(self.buyer_tax_no, 'to_alipay_dict'):
                params['buyer_tax_no'] = self.buyer_tax_no.to_alipay_dict()
            else:
                params['buyer_tax_no'] = self.buyer_tax_no
        if self.buyer_telephone:
            if hasattr(self.buyer_telephone, 'to_alipay_dict'):
                params['buyer_telephone'] = self.buyer_telephone.to_alipay_dict()
            else:
                params['buyer_telephone'] = self.buyer_telephone
        if self.can_link:
            if hasattr(self.can_link, 'to_alipay_dict'):
                params['can_link'] = self.can_link.to_alipay_dict()
            else:
                params['can_link'] = self.can_link
        if self.creator:
            if hasattr(self.creator, 'to_alipay_dict'):
                params['creator'] = self.creator.to_alipay_dict()
            else:
                params['creator'] = self.creator
        if self.drawer:
            if hasattr(self.drawer, 'to_alipay_dict'):
                params['drawer'] = self.drawer.to_alipay_dict()
            else:
                params['drawer'] = self.drawer
        if self.elc_invoice_url:
            if hasattr(self.elc_invoice_url, 'to_alipay_dict'):
                params['elc_invoice_url'] = self.elc_invoice_url.to_alipay_dict()
            else:
                params['elc_invoice_url'] = self.elc_invoice_url
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.invoice_amt:
            if hasattr(self.invoice_amt, 'to_alipay_dict'):
                params['invoice_amt'] = self.invoice_amt.to_alipay_dict()
            else:
                params['invoice_amt'] = self.invoice_amt
        if self.invoice_channel:
            if hasattr(self.invoice_channel, 'to_alipay_dict'):
                params['invoice_channel'] = self.invoice_channel.to_alipay_dict()
            else:
                params['invoice_channel'] = self.invoice_channel
        if self.invoice_code:
            if hasattr(self.invoice_code, 'to_alipay_dict'):
                params['invoice_code'] = self.invoice_code.to_alipay_dict()
            else:
                params['invoice_code'] = self.invoice_code
        if self.invoice_date:
            if hasattr(self.invoice_date, 'to_alipay_dict'):
                params['invoice_date'] = self.invoice_date.to_alipay_dict()
            else:
                params['invoice_date'] = self.invoice_date
        if self.invoice_id:
            if hasattr(self.invoice_id, 'to_alipay_dict'):
                params['invoice_id'] = self.invoice_id.to_alipay_dict()
            else:
                params['invoice_id'] = self.invoice_id
        if self.invoice_material:
            if hasattr(self.invoice_material, 'to_alipay_dict'):
                params['invoice_material'] = self.invoice_material.to_alipay_dict()
            else:
                params['invoice_material'] = self.invoice_material
        if self.invoice_no:
            if hasattr(self.invoice_no, 'to_alipay_dict'):
                params['invoice_no'] = self.invoice_no.to_alipay_dict()
            else:
                params['invoice_no'] = self.invoice_no
        if self.invoice_note:
            if hasattr(self.invoice_note, 'to_alipay_dict'):
                params['invoice_note'] = self.invoice_note.to_alipay_dict()
            else:
                params['invoice_note'] = self.invoice_note
        if self.invoice_status:
            if hasattr(self.invoice_status, 'to_alipay_dict'):
                params['invoice_status'] = self.invoice_status.to_alipay_dict()
            else:
                params['invoice_status'] = self.invoice_status
        if self.invoice_type:
            if hasattr(self.invoice_type, 'to_alipay_dict'):
                params['invoice_type'] = self.invoice_type.to_alipay_dict()
            else:
                params['invoice_type'] = self.invoice_type
        if self.ip_id:
            if hasattr(self.ip_id, 'to_alipay_dict'):
                params['ip_id'] = self.ip_id.to_alipay_dict()
            else:
                params['ip_id'] = self.ip_id
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.last_moder:
            if hasattr(self.last_moder, 'to_alipay_dict'):
                params['last_moder'] = self.last_moder.to_alipay_dict()
            else:
                params['last_moder'] = self.last_moder
        if self.linked_amt:
            if hasattr(self.linked_amt, 'to_alipay_dict'):
                params['linked_amt'] = self.linked_amt.to_alipay_dict()
            else:
                params['linked_amt'] = self.linked_amt
        if self.mail_status:
            if hasattr(self.mail_status, 'to_alipay_dict'):
                params['mail_status'] = self.mail_status.to_alipay_dict()
            else:
                params['mail_status'] = self.mail_status
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.no_bill_invoice_flag:
            if hasattr(self.no_bill_invoice_flag, 'to_alipay_dict'):
                params['no_bill_invoice_flag'] = self.no_bill_invoice_flag.to_alipay_dict()
            else:
                params['no_bill_invoice_flag'] = self.no_bill_invoice_flag
        if self.online:
            if hasattr(self.online, 'to_alipay_dict'):
                params['online'] = self.online.to_alipay_dict()
            else:
                params['online'] = self.online
        if self.payee:
            if hasattr(self.payee, 'to_alipay_dict'):
                params['payee'] = self.payee.to_alipay_dict()
            else:
                params['payee'] = self.payee
        if self.recent_mail_id:
            if hasattr(self.recent_mail_id, 'to_alipay_dict'):
                params['recent_mail_id'] = self.recent_mail_id.to_alipay_dict()
            else:
                params['recent_mail_id'] = self.recent_mail_id
        if self.red:
            if hasattr(self.red, 'to_alipay_dict'):
                params['red'] = self.red.to_alipay_dict()
            else:
                params['red'] = self.red
        if self.red_amt:
            if hasattr(self.red_amt, 'to_alipay_dict'):
                params['red_amt'] = self.red_amt.to_alipay_dict()
            else:
                params['red_amt'] = self.red_amt
        if self.reviewer:
            if hasattr(self.reviewer, 'to_alipay_dict'):
                params['reviewer'] = self.reviewer.to_alipay_dict()
            else:
                params['reviewer'] = self.reviewer
        if self.seller_address:
            if hasattr(self.seller_address, 'to_alipay_dict'):
                params['seller_address'] = self.seller_address.to_alipay_dict()
            else:
                params['seller_address'] = self.seller_address
        if self.seller_bank_account:
            if hasattr(self.seller_bank_account, 'to_alipay_dict'):
                params['seller_bank_account'] = self.seller_bank_account.to_alipay_dict()
            else:
                params['seller_bank_account'] = self.seller_bank_account
        if self.seller_bank_name:
            if hasattr(self.seller_bank_name, 'to_alipay_dict'):
                params['seller_bank_name'] = self.seller_bank_name.to_alipay_dict()
            else:
                params['seller_bank_name'] = self.seller_bank_name
        if self.seller_company_name:
            if hasattr(self.seller_company_name, 'to_alipay_dict'):
                params['seller_company_name'] = self.seller_company_name.to_alipay_dict()
            else:
                params['seller_company_name'] = self.seller_company_name
        if self.seller_tax_no:
            if hasattr(self.seller_tax_no, 'to_alipay_dict'):
                params['seller_tax_no'] = self.seller_tax_no.to_alipay_dict()
            else:
                params['seller_tax_no'] = self.seller_tax_no
        if self.seller_telephone:
            if hasattr(self.seller_telephone, 'to_alipay_dict'):
                params['seller_telephone'] = self.seller_telephone.to_alipay_dict()
            else:
                params['seller_telephone'] = self.seller_telephone
        if self.tnt_inst_id:
            if hasattr(self.tnt_inst_id, 'to_alipay_dict'):
                params['tnt_inst_id'] = self.tnt_inst_id.to_alipay_dict()
            else:
                params['tnt_inst_id'] = self.tnt_inst_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ArRelInvoiceOpenApiResponse()
        if 'ar_invoice_lines' in d:
            o.ar_invoice_lines = d['ar_invoice_lines']
        if 'buyer_address' in d:
            o.buyer_address = d['buyer_address']
        if 'buyer_bank_account' in d:
            o.buyer_bank_account = d['buyer_bank_account']
        if 'buyer_bank_name' in d:
            o.buyer_bank_name = d['buyer_bank_name']
        if 'buyer_invoice_title' in d:
            o.buyer_invoice_title = d['buyer_invoice_title']
        if 'buyer_tax_no' in d:
            o.buyer_tax_no = d['buyer_tax_no']
        if 'buyer_telephone' in d:
            o.buyer_telephone = d['buyer_telephone']
        if 'can_link' in d:
            o.can_link = d['can_link']
        if 'creator' in d:
            o.creator = d['creator']
        if 'drawer' in d:
            o.drawer = d['drawer']
        if 'elc_invoice_url' in d:
            o.elc_invoice_url = d['elc_invoice_url']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'invoice_amt' in d:
            o.invoice_amt = d['invoice_amt']
        if 'invoice_channel' in d:
            o.invoice_channel = d['invoice_channel']
        if 'invoice_code' in d:
            o.invoice_code = d['invoice_code']
        if 'invoice_date' in d:
            o.invoice_date = d['invoice_date']
        if 'invoice_id' in d:
            o.invoice_id = d['invoice_id']
        if 'invoice_material' in d:
            o.invoice_material = d['invoice_material']
        if 'invoice_no' in d:
            o.invoice_no = d['invoice_no']
        if 'invoice_note' in d:
            o.invoice_note = d['invoice_note']
        if 'invoice_status' in d:
            o.invoice_status = d['invoice_status']
        if 'invoice_type' in d:
            o.invoice_type = d['invoice_type']
        if 'ip_id' in d:
            o.ip_id = d['ip_id']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'last_moder' in d:
            o.last_moder = d['last_moder']
        if 'linked_amt' in d:
            o.linked_amt = d['linked_amt']
        if 'mail_status' in d:
            o.mail_status = d['mail_status']
        if 'memo' in d:
            o.memo = d['memo']
        if 'no_bill_invoice_flag' in d:
            o.no_bill_invoice_flag = d['no_bill_invoice_flag']
        if 'online' in d:
            o.online = d['online']
        if 'payee' in d:
            o.payee = d['payee']
        if 'recent_mail_id' in d:
            o.recent_mail_id = d['recent_mail_id']
        if 'red' in d:
            o.red = d['red']
        if 'red_amt' in d:
            o.red_amt = d['red_amt']
        if 'reviewer' in d:
            o.reviewer = d['reviewer']
        if 'seller_address' in d:
            o.seller_address = d['seller_address']
        if 'seller_bank_account' in d:
            o.seller_bank_account = d['seller_bank_account']
        if 'seller_bank_name' in d:
            o.seller_bank_name = d['seller_bank_name']
        if 'seller_company_name' in d:
            o.seller_company_name = d['seller_company_name']
        if 'seller_tax_no' in d:
            o.seller_tax_no = d['seller_tax_no']
        if 'seller_telephone' in d:
            o.seller_telephone = d['seller_telephone']
        if 'tnt_inst_id' in d:
            o.tnt_inst_id = d['tnt_inst_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAuthUnifygwtestQueryModel(object):

    def __init__(self):
        self._str = None

    @property
    def str(self):
        return self._str

    @str.setter
    def str(self, value):
        self._str = value


    def to_alipay_dict(self):
        params = dict()
        if self.str:
            if hasattr(self.str, 'to_alipay_dict'):
                params['str'] = self.str.to_alipay_dict()
            else:
                params['str'] = self.str
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAuthUnifygwtestQueryModel()
        if 'str' in d:
            o.str = d['str']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BizfmcgGoods import BizfmcgGoods


class AlipayCommerceGoodsVoucherBatchqueryModel(object):

    def __init__(self):
        self._goods_list = None
        self._isv_pid = None
        self._merchant_pid = None

    @property
    def goods_list(self):
        return self._goods_list

    @goods_list.setter
    def goods_list(self, value):
        if isinstance(value, BizfmcgGoods):
            self._goods_list = value
        else:
            self._goods_list = BizfmcgGoods.from_alipay_dict(value)
    @property
    def isv_pid(self):
        return self._isv_pid

    @isv_pid.setter
    def isv_pid(self, value):
        self._isv_pid = value
    @property
    def merchant_pid(self):
        return self._merchant_pid

    @merchant_pid.setter
    def merchant_pid(self, value):
        self._merchant_pid = value


    def to_alipay_dict(self):
        params = dict()
        if self.goods_list:
            if hasattr(self.goods_list, 'to_alipay_dict'):
                params['goods_list'] = self.goods_list.to_alipay_dict()
            else:
                params['goods_list'] = self.goods_list
        if self.isv_pid:
            if hasattr(self.isv_pid, 'to_alipay_dict'):
                params['isv_pid'] = self.isv_pid.to_alipay_dict()
            else:
                params['isv_pid'] = self.isv_pid
        if self.merchant_pid:
            if hasattr(self.merchant_pid, 'to_alipay_dict'):
                params['merchant_pid'] = self.merchant_pid.to_alipay_dict()
            else:
                params['merchant_pid'] = self.merchant_pid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceGoodsVoucherBatchqueryModel()
        if 'goods_list' in d:
            o.goods_list = d['goods_list']
        if 'isv_pid' in d:
            o.isv_pid = d['isv_pid']
        if 'merchant_pid' in d:
            o.merchant_pid = d['merchant_pid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MemoElement import MemoElement


class InstRuleCustomMemoVO(object):

    def __init__(self):
        self._element_list = None
        self._split_str = None

    @property
    def element_list(self):
        return self._element_list

    @element_list.setter
    def element_list(self, value):
        if isinstance(value, list):
            self._element_list = list()
            for i in value:
                if isinstance(i, MemoElement):
                    self._element_list.append(i)
                else:
                    self._element_list.append(MemoElement.from_alipay_dict(i))
    @property
    def split_str(self):
        return self._split_str

    @split_str.setter
    def split_str(self, value):
        self._split_str = value


    def to_alipay_dict(self):
        params = dict()
        if self.element_list:
            if isinstance(self.element_list, list):
                for i in range(0, len(self.element_list)):
                    element = self.element_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.element_list[i] = element.to_alipay_dict()
            if hasattr(self.element_list, 'to_alipay_dict'):
                params['element_list'] = self.element_list.to_alipay_dict()
            else:
                params['element_list'] = self.element_list
        if self.split_str:
            if hasattr(self.split_str, 'to_alipay_dict'):
                params['split_str'] = self.split_str.to_alipay_dict()
            else:
                params['split_str'] = self.split_str
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InstRuleCustomMemoVO()
        if 'element_list' in d:
            o.element_list = d['element_list']
        if 'split_str' in d:
            o.split_str = d['split_str']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PosCookDishCateModel import PosCookDishCateModel
from alipay.aop.api.domain.PosCookDishQryDetailModel import PosCookDishQryDetailModel


class PosCookDishQryModel(object):

    def __init__(self):
        self._cate_list = None
        self._dish_list = None

    @property
    def cate_list(self):
        return self._cate_list

    @cate_list.setter
    def cate_list(self, value):
        if isinstance(value, list):
            self._cate_list = list()
            for i in value:
                if isinstance(i, PosCookDishCateModel):
                    self._cate_list.append(i)
                else:
                    self._cate_list.append(PosCookDishCateModel.from_alipay_dict(i))
    @property
    def dish_list(self):
        return self._dish_list

    @dish_list.setter
    def dish_list(self, value):
        if isinstance(value, list):
            self._dish_list = list()
            for i in value:
                if isinstance(i, PosCookDishQryDetailModel):
                    self._dish_list.append(i)
                else:
                    self._dish_list.append(PosCookDishQryDetailModel.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.cate_list:
            if isinstance(self.cate_list, list):
                for i in range(0, len(self.cate_list)):
                    element = self.cate_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.cate_list[i] = element.to_alipay_dict()
            if hasattr(self.cate_list, 'to_alipay_dict'):
                params['cate_list'] = self.cate_list.to_alipay_dict()
            else:
                params['cate_list'] = self.cate_list
        if self.dish_list:
            if isinstance(self.dish_list, list):
                for i in range(0, len(self.dish_list)):
                    element = self.dish_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.dish_list[i] = element.to_alipay_dict()
            if hasattr(self.dish_list, 'to_alipay_dict'):
                params['dish_list'] = self.dish_list.to_alipay_dict()
            else:
                params['dish_list'] = self.dish_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PosCookDishQryModel()
        if 'cate_list' in d:
            o.cate_list = d['cate_list']
        if 'dish_list' in d:
            o.dish_list = d['dish_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityRiskAuthenticationInitializeResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityRiskAuthenticationInitializeResponse, self).__init__()
        self._biz_result = None
        self._token_id = None

    @property
    def biz_result(self):
        return self._biz_result

    @biz_result.setter
    def biz_result(self, value):
        self._biz_result = value
    @property
    def token_id(self):
        return self._token_id

    @token_id.setter
    def token_id(self, value):
        self._token_id = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityRiskAuthenticationInitializeResponse, self).parse_response_content(response_content)
        if 'biz_result' in response:
            self.biz_result = response['biz_result']
        if 'token_id' in response:
            self.token_id = response['token_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AgreementLimitMerchant import AgreementLimitMerchant


class AlipayFundAllocSignQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundAllocSignQueryResponse, self).__init__()
        self._agreement_no = None
        self._alloc_upper_limit = None
        self._invalid_time = None
        self._principal_id = None
        self._principal_open_id = None
        self._status = None
        self._support_merchant_list = None
        self._valid_strat_time = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def alloc_upper_limit(self):
        return self._alloc_upper_limit

    @alloc_upper_limit.setter
    def alloc_upper_limit(self, value):
        self._alloc_upper_limit = value
    @property
    def invalid_time(self):
        return self._invalid_time

    @invalid_time.setter
    def invalid_time(self, value):
        self._invalid_time = value
    @property
    def principal_id(self):
        return self._principal_id

    @principal_id.setter
    def principal_id(self, value):
        self._principal_id = value
    @property
    def principal_open_id(self):
        return self._principal_open_id

    @principal_open_id.setter
    def principal_open_id(self, value):
        self._principal_open_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def support_merchant_list(self):
        return self._support_merchant_list

    @support_merchant_list.setter
    def support_merchant_list(self, value):
        if isinstance(value, list):
            self._support_merchant_list = list()
            for i in value:
                if isinstance(i, AgreementLimitMerchant):
                    self._support_merchant_list.append(i)
                else:
                    self._support_merchant_list.append(AgreementLimitMerchant.from_alipay_dict(i))
    @property
    def valid_strat_time(self):
        return self._valid_strat_time

    @valid_strat_time.setter
    def valid_strat_time(self, value):
        self._valid_strat_time = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundAllocSignQueryResponse, self).parse_response_content(response_content)
        if 'agreement_no' in response:
            self.agreement_no = response['agreement_no']
        if 'alloc_upper_limit' in response:
            self.alloc_upper_limit = response['alloc_upper_limit']
        if 'invalid_time' in response:
            self.invalid_time = response['invalid_time']
        if 'principal_id' in response:
            self.principal_id = response['principal_id']
        if 'principal_open_id' in response:
            self.principal_open_id = response['principal_open_id']
        if 'status' in response:
            self.status = response['status']
        if 'support_merchant_list' in response:
            self.support_merchant_list = response['support_merchant_list']
        if 'valid_strat_time' in response:
            self.valid_strat_time = response['valid_strat_time']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AmpeDeviceVO(object):

    def __init__(self):
        self._add_time = None
        self._device_id = None
        self._model_id = None
        self._model_name = None
        self._model_no = None
        self._product_id = None
        self._product_name = None

    @property
    def add_time(self):
        return self._add_time

    @add_time.setter
    def add_time(self, value):
        self._add_time = value
    @property
    def device_id(self):
        return self._device_id

    @device_id.setter
    def device_id(self, value):
        self._device_id = value
    @property
    def model_id(self):
        return self._model_id

    @model_id.setter
    def model_id(self, value):
        self._model_id = value
    @property
    def model_name(self):
        return self._model_name

    @model_name.setter
    def model_name(self, value):
        self._model_name = value
    @property
    def model_no(self):
        return self._model_no

    @model_no.setter
    def model_no(self, value):
        self._model_no = value
    @property
    def product_id(self):
        return self._product_id

    @product_id.setter
    def product_id(self, value):
        self._product_id = value
    @property
    def product_name(self):
        return self._product_name

    @product_name.setter
    def product_name(self, value):
        self._product_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.add_time:
            if hasattr(self.add_time, 'to_alipay_dict'):
                params['add_time'] = self.add_time.to_alipay_dict()
            else:
                params['add_time'] = self.add_time
        if self.device_id:
            if hasattr(self.device_id, 'to_alipay_dict'):
                params['device_id'] = self.device_id.to_alipay_dict()
            else:
                params['device_id'] = self.device_id
        if self.model_id:
            if hasattr(self.model_id, 'to_alipay_dict'):
                params['model_id'] = self.model_id.to_alipay_dict()
            else:
                params['model_id'] = self.model_id
        if self.model_name:
            if hasattr(self.model_name, 'to_alipay_dict'):
                params['model_name'] = self.model_name.to_alipay_dict()
            else:
                params['model_name'] = self.model_name
        if self.model_no:
            if hasattr(self.model_no, 'to_alipay_dict'):
                params['model_no'] = self.model_no.to_alipay_dict()
            else:
                params['model_no'] = self.model_no
        if self.product_id:
            if hasattr(self.product_id, 'to_alipay_dict'):
                params['product_id'] = self.product_id.to_alipay_dict()
            else:
                params['product_id'] = self.product_id
        if self.product_name:
            if hasattr(self.product_name, 'to_alipay_dict'):
                params['product_name'] = self.product_name.to_alipay_dict()
            else:
                params['product_name'] = self.product_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AmpeDeviceVO()
        if 'add_time' in d:
            o.add_time = d['add_time']
        if 'device_id' in d:
            o.device_id = d['device_id']
        if 'model_id' in d:
            o.model_id = d['model_id']
        if 'model_name' in d:
            o.model_name = d['model_name']
        if 'model_no' in d:
            o.model_no = d['model_no']
        if 'product_id' in d:
            o.product_id = d['product_id']
        if 'product_name' in d:
            o.product_name = d['product_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class KoubeiTradeTicketTicketcodeCheckavailableResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiTradeTicketTicketcodeCheckavailableResponse, self).__init__()
        self._biz_code = None
        self._request_id = None

    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value

    def parse_response_content(self, response_content):
        response = super(KoubeiTradeTicketTicketcodeCheckavailableResponse, self).parse_response_content(response_content)
        if 'biz_code' in response:
            self.biz_code = response['biz_code']
        if 'request_id' in response:
            self.request_id = response['request_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class Terminal(object):

    def __init__(self):
        self._mac = None
        self._os = None
        self._os_arch = None
        self._os_version = None
        self._terminal_type = None
        self._terminal_version = None

    @property
    def mac(self):
        return self._mac

    @mac.setter
    def mac(self, value):
        self._mac = value
    @property
    def os(self):
        return self._os

    @os.setter
    def os(self, value):
        self._os = value
    @property
    def os_arch(self):
        return self._os_arch

    @os_arch.setter
    def os_arch(self, value):
        self._os_arch = value
    @property
    def os_version(self):
        return self._os_version

    @os_version.setter
    def os_version(self, value):
        self._os_version = value
    @property
    def terminal_type(self):
        return self._terminal_type

    @terminal_type.setter
    def terminal_type(self, value):
        self._terminal_type = value
    @property
    def terminal_version(self):
        return self._terminal_version

    @terminal_version.setter
    def terminal_version(self, value):
        self._terminal_version = value


    def to_alipay_dict(self):
        params = dict()
        if self.mac:
            if hasattr(self.mac, 'to_alipay_dict'):
                params['mac'] = self.mac.to_alipay_dict()
            else:
                params['mac'] = self.mac
        if self.os:
            if hasattr(self.os, 'to_alipay_dict'):
                params['os'] = self.os.to_alipay_dict()
            else:
                params['os'] = self.os
        if self.os_arch:
            if hasattr(self.os_arch, 'to_alipay_dict'):
                params['os_arch'] = self.os_arch.to_alipay_dict()
            else:
                params['os_arch'] = self.os_arch
        if self.os_version:
            if hasattr(self.os_version, 'to_alipay_dict'):
                params['os_version'] = self.os_version.to_alipay_dict()
            else:
                params['os_version'] = self.os_version
        if self.terminal_type:
            if hasattr(self.terminal_type, 'to_alipay_dict'):
                params['terminal_type'] = self.terminal_type.to_alipay_dict()
            else:
                params['terminal_type'] = self.terminal_type
        if self.terminal_version:
            if hasattr(self.terminal_version, 'to_alipay_dict'):
                params['terminal_version'] = self.terminal_version.to_alipay_dict()
            else:
                params['terminal_version'] = self.terminal_version
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = Terminal()
        if 'mac' in d:
            o.mac = d['mac']
        if 'os' in d:
            o.os = d['os']
        if 'os_arch' in d:
            o.os_arch = d['os_arch']
        if 'os_version' in d:
            o.os_version = d['os_version']
        if 'terminal_type' in d:
            o.terminal_type = d['terminal_type']
        if 'terminal_version' in d:
            o.terminal_version = d['terminal_version']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppIndustryClearApplyModel(object):

    def __init__(self):
        self._biz_type = None
        self._business_date = None
        self._memo = None
        self._org_code = None
        self._passive_no = None
        self._sub_org_code = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def business_date(self):
        return self._business_date

    @business_date.setter
    def business_date(self, value):
        self._business_date = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def org_code(self):
        return self._org_code

    @org_code.setter
    def org_code(self, value):
        self._org_code = value
    @property
    def passive_no(self):
        return self._passive_no

    @passive_no.setter
    def passive_no(self, value):
        self._passive_no = value
    @property
    def sub_org_code(self):
        return self._sub_org_code

    @sub_org_code.setter
    def sub_org_code(self, value):
        self._sub_org_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.business_date:
            if hasattr(self.business_date, 'to_alipay_dict'):
                params['business_date'] = self.business_date.to_alipay_dict()
            else:
                params['business_date'] = self.business_date
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.org_code:
            if hasattr(self.org_code, 'to_alipay_dict'):
                params['org_code'] = self.org_code.to_alipay_dict()
            else:
                params['org_code'] = self.org_code
        if self.passive_no:
            if hasattr(self.passive_no, 'to_alipay_dict'):
                params['passive_no'] = self.passive_no.to_alipay_dict()
            else:
                params['passive_no'] = self.passive_no
        if self.sub_org_code:
            if hasattr(self.sub_org_code, 'to_alipay_dict'):
                params['sub_org_code'] = self.sub_org_code.to_alipay_dict()
            else:
                params['sub_org_code'] = self.sub_org_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppIndustryClearApplyModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'business_date' in d:
            o.business_date = d['business_date']
        if 'memo' in d:
            o.memo = d['memo']
        if 'org_code' in d:
            o.org_code = d['org_code']
        if 'passive_no' in d:
            o.passive_no = d['passive_no']
        if 'sub_org_code' in d:
            o.sub_org_code = d['sub_org_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CompanyDetail import CompanyDetail


class AlipayBossProdCompanyQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayBossProdCompanyQueryResponse, self).__init__()
        self._open_api_company_query_result = None

    @property
    def open_api_company_query_result(self):
        return self._open_api_company_query_result

    @open_api_company_query_result.setter
    def open_api_company_query_result(self, value):
        if isinstance(value, list):
            self._open_api_company_query_result = list()
            for i in value:
                if isinstance(i, CompanyDetail):
                    self._open_api_company_query_result.append(i)
                else:
                    self._open_api_company_query_result.append(CompanyDetail.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayBossProdCompanyQueryResponse, self).parse_response_content(response_content)
        if 'open_api_company_query_result' in response:
            self.open_api_company_query_result = response['open_api_company_query_result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InsAddressee import InsAddressee
from alipay.aop.api.domain.InsInvoiceApplyItem import InsInvoiceApplyItem


class AlipayInsSceneInvoiceApplyModel(object):

    def __init__(self):
        self._delivery_type = None
        self._invoice_addressee = None
        self._invoice_apply_item = None
        self._invoice_date = None
        self._invoice_title = None
        self._invoice_type = None
        self._out_biz_no = None
        self._out_request_no = None

    @property
    def delivery_type(self):
        return self._delivery_type

    @delivery_type.setter
    def delivery_type(self, value):
        self._delivery_type = value
    @property
    def invoice_addressee(self):
        return self._invoice_addressee

    @invoice_addressee.setter
    def invoice_addressee(self, value):
        if isinstance(value, InsAddressee):
            self._invoice_addressee = value
        else:
            self._invoice_addressee = InsAddressee.from_alipay_dict(value)
    @property
    def invoice_apply_item(self):
        return self._invoice_apply_item

    @invoice_apply_item.setter
    def invoice_apply_item(self, value):
        if isinstance(value, InsInvoiceApplyItem):
            self._invoice_apply_item = value
        else:
            self._invoice_apply_item = InsInvoiceApplyItem.from_alipay_dict(value)
    @property
    def invoice_date(self):
        return self._invoice_date

    @invoice_date.setter
    def invoice_date(self, value):
        self._invoice_date = value
    @property
    def invoice_title(self):
        return self._invoice_title

    @invoice_title.setter
    def invoice_title(self, value):
        self._invoice_title = value
    @property
    def invoice_type(self):
        return self._invoice_type

    @invoice_type.setter
    def invoice_type(self, value):
        self._invoice_type = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.delivery_type:
            if hasattr(self.delivery_type, 'to_alipay_dict'):
                params['delivery_type'] = self.delivery_type.to_alipay_dict()
            else:
                params['delivery_type'] = self.delivery_type
        if self.invoice_addressee:
            if hasattr(self.invoice_addressee, 'to_alipay_dict'):
                params['invoice_addressee'] = self.invoice_addressee.to_alipay_dict()
            else:
                params['invoice_addressee'] = self.invoice_addressee
        if self.invoice_apply_item:
            if hasattr(self.invoice_apply_item, 'to_alipay_dict'):
                params['invoice_apply_item'] = self.invoice_apply_item.to_alipay_dict()
            else:
                params['invoice_apply_item'] = self.invoice_apply_item
        if self.invoice_date:
            if hasattr(self.invoice_date, 'to_alipay_dict'):
                params['invoice_date'] = self.invoice_date.to_alipay_dict()
            else:
                params['invoice_date'] = self.invoice_date
        if self.invoice_title:
            if hasattr(self.invoice_title, 'to_alipay_dict'):
                params['invoice_title'] = self.invoice_title.to_alipay_dict()
            else:
                params['invoice_title'] = self.invoice_title
        if self.invoice_type:
            if hasattr(self.invoice_type, 'to_alipay_dict'):
                params['invoice_type'] = self.invoice_type.to_alipay_dict()
            else:
                params['invoice_type'] = self.invoice_type
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneInvoiceApplyModel()
        if 'delivery_type' in d:
            o.delivery_type = d['delivery_type']
        if 'invoice_addressee' in d:
            o.invoice_addressee = d['invoice_addressee']
        if 'invoice_apply_item' in d:
            o.invoice_apply_item = d['invoice_apply_item']
        if 'invoice_date' in d:
            o.invoice_date = d['invoice_date']
        if 'invoice_title' in d:
            o.invoice_title = d['invoice_title']
        if 'invoice_type' in d:
            o.invoice_type = d['invoice_type']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AnttechBlockchainFinanceTruspleCustomsauthinitSubmitResponse(AlipayResponse):

    def __init__(self):
        super(AnttechBlockchainFinanceTruspleCustomsauthinitSubmitResponse, self).__init__()
        self._agreement_no = None
        self._auth_required = None
        self._end_date = None
        self._org_code = None
        self._start_date = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def auth_required(self):
        return self._auth_required

    @auth_required.setter
    def auth_required(self, value):
        self._auth_required = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def org_code(self):
        return self._org_code

    @org_code.setter
    def org_code(self, value):
        self._org_code = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value

    def parse_response_content(self, response_content):
        response = super(AnttechBlockchainFinanceTruspleCustomsauthinitSubmitResponse, self).parse_response_content(response_content)
        if 'agreement_no' in response:
            self.agreement_no = response['agreement_no']
        if 'auth_required' in response:
            self.auth_required = response['auth_required']
        if 'end_date' in response:
            self.end_date = response['end_date']
        if 'org_code' in response:
            self.org_code = response['org_code']
        if 'start_date' in response:
            self.start_date = response['start_date']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ZhimaRiskDetail import ZhimaRiskDetail


class AliTrustRiskIdentify(object):

    def __init__(self):
        self._details = None
        self._is_risk = None
        self._risk_tag = None

    @property
    def details(self):
        return self._details

    @details.setter
    def details(self, value):
        if isinstance(value, list):
            self._details = list()
            for i in value:
                if isinstance(i, ZhimaRiskDetail):
                    self._details.append(i)
                else:
                    self._details.append(ZhimaRiskDetail.from_alipay_dict(i))
    @property
    def is_risk(self):
        return self._is_risk

    @is_risk.setter
    def is_risk(self, value):
        self._is_risk = value
    @property
    def risk_tag(self):
        return self._risk_tag

    @risk_tag.setter
    def risk_tag(self, value):
        self._risk_tag = value


    def to_alipay_dict(self):
        params = dict()
        if self.details:
            if isinstance(self.details, list):
                for i in range(0, len(self.details)):
                    element = self.details[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.details[i] = element.to_alipay_dict()
            if hasattr(self.details, 'to_alipay_dict'):
                params['details'] = self.details.to_alipay_dict()
            else:
                params['details'] = self.details
        if self.is_risk:
            if hasattr(self.is_risk, 'to_alipay_dict'):
                params['is_risk'] = self.is_risk.to_alipay_dict()
            else:
                params['is_risk'] = self.is_risk
        if self.risk_tag:
            if hasattr(self.risk_tag, 'to_alipay_dict'):
                params['risk_tag'] = self.risk_tag.to_alipay_dict()
            else:
                params['risk_tag'] = self.risk_tag
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AliTrustRiskIdentify()
        if 'details' in d:
            o.details = d['details']
        if 'is_risk' in d:
            o.is_risk = d['is_risk']
        if 'risk_tag' in d:
            o.risk_tag = d['risk_tag']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPcreditHuabeiAuthSignApplyModel(object):

    def __init__(self):
        self._alipay_user_id = None
        self._channel = None
        self._freeze_amount = None
        self._open_id = None
        self._out_request_no = None
        self._out_sign_no = None
        self._seller_id = None
        self._template_id = None
        self._timeout_express = None

    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def freeze_amount(self):
        return self._freeze_amount

    @freeze_amount.setter
    def freeze_amount(self, value):
        self._freeze_amount = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def out_sign_no(self):
        return self._out_sign_no

    @out_sign_no.setter
    def out_sign_no(self, value):
        self._out_sign_no = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value
    @property
    def timeout_express(self):
        return self._timeout_express

    @timeout_express.setter
    def timeout_express(self, value):
        self._timeout_express = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.channel:
            if hasattr(self.channel, 'to_alipay_dict'):
                params['channel'] = self.channel.to_alipay_dict()
            else:
                params['channel'] = self.channel
        if self.freeze_amount:
            if hasattr(self.freeze_amount, 'to_alipay_dict'):
                params['freeze_amount'] = self.freeze_amount.to_alipay_dict()
            else:
                params['freeze_amount'] = self.freeze_amount
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.out_sign_no:
            if hasattr(self.out_sign_no, 'to_alipay_dict'):
                params['out_sign_no'] = self.out_sign_no.to_alipay_dict()
            else:
                params['out_sign_no'] = self.out_sign_no
        if self.seller_id:
            if hasattr(self.seller_id, 'to_alipay_dict'):
                params['seller_id'] = self.seller_id.to_alipay_dict()
            else:
                params['seller_id'] = self.seller_id
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        if self.timeout_express:
            if hasattr(self.timeout_express, 'to_alipay_dict'):
                params['timeout_express'] = self.timeout_express.to_alipay_dict()
            else:
                params['timeout_express'] = self.timeout_express
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPcreditHuabeiAuthSignApplyModel()
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'channel' in d:
            o.channel = d['channel']
        if 'freeze_amount' in d:
            o.freeze_amount = d['freeze_amount']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'out_sign_no' in d:
            o.out_sign_no = d['out_sign_no']
        if 'seller_id' in d:
            o.seller_id = d['seller_id']
        if 'template_id' in d:
            o.template_id = d['template_id']
        if 'timeout_express' in d:
            o.timeout_express = d['timeout_express']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class DatadigitalFincloudFinsaasDesignPageModifyResponse(AlipayResponse):

    def __init__(self):
        super(DatadigitalFincloudFinsaasDesignPageModifyResponse, self).__init__()
        self._page_code = None
        self._page_id = None

    @property
    def page_code(self):
        return self._page_code

    @page_code.setter
    def page_code(self, value):
        self._page_code = value
    @property
    def page_id(self):
        return self._page_id

    @page_id.setter
    def page_id(self, value):
        self._page_id = value

    def parse_response_content(self, response_content):
        response = super(DatadigitalFincloudFinsaasDesignPageModifyResponse, self).parse_response_content(response_content)
        if 'page_code' in response:
            self.page_code = response['page_code']
        if 'page_id' in response:
            self.page_id = response['page_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi


class InvoiceResponseDTO(object):

    def __init__(self):
        self._exclude_tax_invoice_amt = None
        self._invoice_amt = None
        self._invoice_code = None
        self._invoice_date = None
        self._invoice_id = None
        self._invoice_no = None
        self._invoice_rcv_date = None
        self._invoice_status = None
        self._invoice_type = None
        self._invoice_type_name = None
        self._tax_amt = None
        self._tax_rate = None

    @property
    def exclude_tax_invoice_amt(self):
        return self._exclude_tax_invoice_amt

    @exclude_tax_invoice_amt.setter
    def exclude_tax_invoice_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._exclude_tax_invoice_amt = value
        else:
            self._exclude_tax_invoice_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def invoice_amt(self):
        return self._invoice_amt

    @invoice_amt.setter
    def invoice_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._invoice_amt = value
        else:
            self._invoice_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def invoice_code(self):
        return self._invoice_code

    @invoice_code.setter
    def invoice_code(self, value):
        self._invoice_code = value
    @property
    def invoice_date(self):
        return self._invoice_date

    @invoice_date.setter
    def invoice_date(self, value):
        self._invoice_date = value
    @property
    def invoice_id(self):
        return self._invoice_id

    @invoice_id.setter
    def invoice_id(self, value):
        self._invoice_id = value
    @property
    def invoice_no(self):
        return self._invoice_no

    @invoice_no.setter
    def invoice_no(self, value):
        self._invoice_no = value
    @property
    def invoice_rcv_date(self):
        return self._invoice_rcv_date

    @invoice_rcv_date.setter
    def invoice_rcv_date(self, value):
        self._invoice_rcv_date = value
    @property
    def invoice_status(self):
        return self._invoice_status

    @invoice_status.setter
    def invoice_status(self, value):
        self._invoice_status = value
    @property
    def invoice_type(self):
        return self._invoice_type

    @invoice_type.setter
    def invoice_type(self, value):
        self._invoice_type = value
    @property
    def invoice_type_name(self):
        return self._invoice_type_name

    @invoice_type_name.setter
    def invoice_type_name(self, value):
        self._invoice_type_name = value
    @property
    def tax_amt(self):
        return self._tax_amt

    @tax_amt.setter
    def tax_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._tax_amt = value
        else:
            self._tax_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def tax_rate(self):
        return self._tax_rate

    @tax_rate.setter
    def tax_rate(self, value):
        self._tax_rate = value


    def to_alipay_dict(self):
        params = dict()
        if self.exclude_tax_invoice_amt:
            if hasattr(self.exclude_tax_invoice_amt, 'to_alipay_dict'):
                params['exclude_tax_invoice_amt'] = self.exclude_tax_invoice_amt.to_alipay_dict()
            else:
                params['exclude_tax_invoice_amt'] = self.exclude_tax_invoice_amt
        if self.invoice_amt:
            if hasattr(self.invoice_amt, 'to_alipay_dict'):
                params['invoice_amt'] = self.invoice_amt.to_alipay_dict()
            else:
                params['invoice_amt'] = self.invoice_amt
        if self.invoice_code:
            if hasattr(self.invoice_code, 'to_alipay_dict'):
                params['invoice_code'] = self.invoice_code.to_alipay_dict()
            else:
                params['invoice_code'] = self.invoice_code
        if self.invoice_date:
            if hasattr(self.invoice_date, 'to_alipay_dict'):
                params['invoice_date'] = self.invoice_date.to_alipay_dict()
            else:
                params['invoice_date'] = self.invoice_date
        if self.invoice_id:
            if hasattr(self.invoice_id, 'to_alipay_dict'):
                params['invoice_id'] = self.invoice_id.to_alipay_dict()
            else:
                params['invoice_id'] = self.invoice_id
        if self.invoice_no:
            if hasattr(self.invoice_no, 'to_alipay_dict'):
                params['invoice_no'] = self.invoice_no.to_alipay_dict()
            else:
                params['invoice_no'] = self.invoice_no
        if self.invoice_rcv_date:
            if hasattr(self.invoice_rcv_date, 'to_alipay_dict'):
                params['invoice_rcv_date'] = self.invoice_rcv_date.to_alipay_dict()
            else:
                params['invoice_rcv_date'] = self.invoice_rcv_date
        if self.invoice_status:
            if hasattr(self.invoice_status, 'to_alipay_dict'):
                params['invoice_status'] = self.invoice_status.to_alipay_dict()
            else:
                params['invoice_status'] = self.invoice_status
        if self.invoice_type:
            if hasattr(self.invoice_type, 'to_alipay_dict'):
                params['invoice_type'] = self.invoice_type.to_alipay_dict()
            else:
                params['invoice_type'] = self.invoice_type
        if self.invoice_type_name:
            if hasattr(self.invoice_type_name, 'to_alipay_dict'):
                params['invoice_type_name'] = self.invoice_type_name.to_alipay_dict()
            else:
                params['invoice_type_name'] = self.invoice_type_name
        if self.tax_amt:
            if hasattr(self.tax_amt, 'to_alipay_dict'):
                params['tax_amt'] = self.tax_amt.to_alipay_dict()
            else:
                params['tax_amt'] = self.tax_amt
        if self.tax_rate:
            if hasattr(self.tax_rate, 'to_alipay_dict'):
                params['tax_rate'] = self.tax_rate.to_alipay_dict()
            else:
                params['tax_rate'] = self.tax_rate
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InvoiceResponseDTO()
        if 'exclude_tax_invoice_amt' in d:
            o.exclude_tax_invoice_amt = d['exclude_tax_invoice_amt']
        if 'invoice_amt' in d:
            o.invoice_amt = d['invoice_amt']
        if 'invoice_code' in d:
            o.invoice_code = d['invoice_code']
        if 'invoice_date' in d:
            o.invoice_date = d['invoice_date']
        if 'invoice_id' in d:
            o.invoice_id = d['invoice_id']
        if 'invoice_no' in d:
            o.invoice_no = d['invoice_no']
        if 'invoice_rcv_date' in d:
            o.invoice_rcv_date = d['invoice_rcv_date']
        if 'invoice_status' in d:
            o.invoice_status = d['invoice_status']
        if 'invoice_type' in d:
            o.invoice_type = d['invoice_type']
        if 'invoice_type_name' in d:
            o.invoice_type_name = d['invoice_type_name']
        if 'tax_amt' in d:
            o.tax_amt = d['tax_amt']
        if 'tax_rate' in d:
            o.tax_rate = d['tax_rate']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SpecifyAttachmentInfo(object):

    def __init__(self):
        self._allow_more_uploads = None
        self._allow_more_uploads_max_count = None
        self._collect_cert_types = None
        self._collect_common_codes = None
        self._third_party_user_id = None

    @property
    def allow_more_uploads(self):
        return self._allow_more_uploads

    @allow_more_uploads.setter
    def allow_more_uploads(self, value):
        self._allow_more_uploads = value
    @property
    def allow_more_uploads_max_count(self):
        return self._allow_more_uploads_max_count

    @allow_more_uploads_max_count.setter
    def allow_more_uploads_max_count(self, value):
        self._allow_more_uploads_max_count = value
    @property
    def collect_cert_types(self):
        return self._collect_cert_types

    @collect_cert_types.setter
    def collect_cert_types(self, value):
        if isinstance(value, list):
            self._collect_cert_types = list()
            for i in value:
                self._collect_cert_types.append(i)
    @property
    def collect_common_codes(self):
        return self._collect_common_codes

    @collect_common_codes.setter
    def collect_common_codes(self, value):
        if isinstance(value, list):
            self._collect_common_codes = list()
            for i in value:
                self._collect_common_codes.append(i)
    @property
    def third_party_user_id(self):
        return self._third_party_user_id

    @third_party_user_id.setter
    def third_party_user_id(self, value):
        self._third_party_user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.allow_more_uploads:
            if hasattr(self.allow_more_uploads, 'to_alipay_dict'):
                params['allow_more_uploads'] = self.allow_more_uploads.to_alipay_dict()
            else:
                params['allow_more_uploads'] = self.allow_more_uploads
        if self.allow_more_uploads_max_count:
            if hasattr(self.allow_more_uploads_max_count, 'to_alipay_dict'):
                params['allow_more_uploads_max_count'] = self.allow_more_uploads_max_count.to_alipay_dict()
            else:
                params['allow_more_uploads_max_count'] = self.allow_more_uploads_max_count
        if self.collect_cert_types:
            if isinstance(self.collect_cert_types, list):
                for i in range(0, len(self.collect_cert_types)):
                    element = self.collect_cert_types[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.collect_cert_types[i] = element.to_alipay_dict()
            if hasattr(self.collect_cert_types, 'to_alipay_dict'):
                params['collect_cert_types'] = self.collect_cert_types.to_alipay_dict()
            else:
                params['collect_cert_types'] = self.collect_cert_types
        if self.collect_common_codes:
            if isinstance(self.collect_common_codes, list):
                for i in range(0, len(self.collect_common_codes)):
                    element = self.collect_common_codes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.collect_common_codes[i] = element.to_alipay_dict()
            if hasattr(self.collect_common_codes, 'to_alipay_dict'):
                params['collect_common_codes'] = self.collect_common_codes.to_alipay_dict()
            else:
                params['collect_common_codes'] = self.collect_common_codes
        if self.third_party_user_id:
            if hasattr(self.third_party_user_id, 'to_alipay_dict'):
                params['third_party_user_id'] = self.third_party_user_id.to_alipay_dict()
            else:
                params['third_party_user_id'] = self.third_party_user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SpecifyAttachmentInfo()
        if 'allow_more_uploads' in d:
            o.allow_more_uploads = d['allow_more_uploads']
        if 'allow_more_uploads_max_count' in d:
            o.allow_more_uploads_max_count = d['allow_more_uploads_max_count']
        if 'collect_cert_types' in d:
            o.collect_cert_types = d['collect_cert_types']
        if 'collect_common_codes' in d:
            o.collect_common_codes = d['collect_common_codes']
        if 'third_party_user_id' in d:
            o.third_party_user_id = d['third_party_user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ActivityShop(object):

    def __init__(self):
        self._shop_address = None
        self._shop_id = None
        self._shop_latitude = None
        self._shop_longitude = None
        self._shop_name = None

    @property
    def shop_address(self):
        return self._shop_address

    @shop_address.setter
    def shop_address(self, value):
        self._shop_address = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def shop_latitude(self):
        return self._shop_latitude

    @shop_latitude.setter
    def shop_latitude(self, value):
        self._shop_latitude = value
    @property
    def shop_longitude(self):
        return self._shop_longitude

    @shop_longitude.setter
    def shop_longitude(self, value):
        self._shop_longitude = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.shop_address:
            if hasattr(self.shop_address, 'to_alipay_dict'):
                params['shop_address'] = self.shop_address.to_alipay_dict()
            else:
                params['shop_address'] = self.shop_address
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.shop_latitude:
            if hasattr(self.shop_latitude, 'to_alipay_dict'):
                params['shop_latitude'] = self.shop_latitude.to_alipay_dict()
            else:
                params['shop_latitude'] = self.shop_latitude
        if self.shop_longitude:
            if hasattr(self.shop_longitude, 'to_alipay_dict'):
                params['shop_longitude'] = self.shop_longitude.to_alipay_dict()
            else:
                params['shop_longitude'] = self.shop_longitude
        if self.shop_name:
            if hasattr(self.shop_name, 'to_alipay_dict'):
                params['shop_name'] = self.shop_name.to_alipay_dict()
            else:
                params['shop_name'] = self.shop_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ActivityShop()
        if 'shop_address' in d:
            o.shop_address = d['shop_address']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'shop_latitude' in d:
            o.shop_latitude = d['shop_latitude']
        if 'shop_longitude' in d:
            o.shop_longitude = d['shop_longitude']
        if 'shop_name' in d:
            o.shop_name = d['shop_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.KbdishAreaFreeInfo import KbdishAreaFreeInfo
from alipay.aop.api.domain.KbdishTabInfo import KbdishTabInfo


class KbdishAreaInfo(object):

    def __init__(self):
        self._area_free_list = None
        self._area_id = None
        self._area_name = None
        self._area_sort = None
        self._create_user = None
        self._fee_price = None
        self._merchant_id = None
        self._shop_id = None
        self._status = None
        self._tab_count = None
        self._tab_list = None
        self._update_user = None

    @property
    def area_free_list(self):
        return self._area_free_list

    @area_free_list.setter
    def area_free_list(self, value):
        if isinstance(value, list):
            self._area_free_list = list()
            for i in value:
                if isinstance(i, KbdishAreaFreeInfo):
                    self._area_free_list.append(i)
                else:
                    self._area_free_list.append(KbdishAreaFreeInfo.from_alipay_dict(i))
    @property
    def area_id(self):
        return self._area_id

    @area_id.setter
    def area_id(self, value):
        self._area_id = value
    @property
    def area_name(self):
        return self._area_name

    @area_name.setter
    def area_name(self, value):
        self._area_name = value
    @property
    def area_sort(self):
        return self._area_sort

    @area_sort.setter
    def area_sort(self, value):
        self._area_sort = value
    @property
    def create_user(self):
        return self._create_user

    @create_user.setter
    def create_user(self, value):
        self._create_user = value
    @property
    def fee_price(self):
        return self._fee_price

    @fee_price.setter
    def fee_price(self, value):
        self._fee_price = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def tab_count(self):
        return self._tab_count

    @tab_count.setter
    def tab_count(self, value):
        self._tab_count = value
    @property
    def tab_list(self):
        return self._tab_list

    @tab_list.setter
    def tab_list(self, value):
        if isinstance(value, list):
            self._tab_list = list()
            for i in value:
                if isinstance(i, KbdishTabInfo):
                    self._tab_list.append(i)
                else:
                    self._tab_list.append(KbdishTabInfo.from_alipay_dict(i))
    @property
    def update_user(self):
        return self._update_user

    @update_user.setter
    def update_user(self, value):
        self._update_user = value


    def to_alipay_dict(self):
        params = dict()
        if self.area_free_list:
            if isinstance(self.area_free_list, list):
                for i in range(0, len(self.area_free_list)):
                    element = self.area_free_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.area_free_list[i] = element.to_alipay_dict()
            if hasattr(self.area_free_list, 'to_alipay_dict'):
                params['area_free_list'] = self.area_free_list.to_alipay_dict()
            else:
                params['area_free_list'] = self.area_free_list
        if self.area_id:
            if hasattr(self.area_id, 'to_alipay_dict'):
                params['area_id'] = self.area_id.to_alipay_dict()
            else:
                params['area_id'] = self.area_id
        if self.area_name:
            if hasattr(self.area_name, 'to_alipay_dict'):
                params['area_name'] = self.area_name.to_alipay_dict()
            else:
                params['area_name'] = self.area_name
        if self.area_sort:
            if hasattr(self.area_sort, 'to_alipay_dict'):
                params['area_sort'] = self.area_sort.to_alipay_dict()
            else:
                params['area_sort'] = self.area_sort
        if self.create_user:
            if hasattr(self.create_user, 'to_alipay_dict'):
                params['create_user'] = self.create_user.to_alipay_dict()
            else:
                params['create_user'] = self.create_user
        if self.fee_price:
            if hasattr(self.fee_price, 'to_alipay_dict'):
                params['fee_price'] = self.fee_price.to_alipay_dict()
            else:
                params['fee_price'] = self.fee_price
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.tab_count:
            if hasattr(self.tab_count, 'to_alipay_dict'):
                params['tab_count'] = self.tab_count.to_alipay_dict()
            else:
                params['tab_count'] = self.tab_count
        if self.tab_list:
            if isinstance(self.tab_list, list):
                for i in range(0, len(self.tab_list)):
                    element = self.tab_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.tab_list[i] = element.to_alipay_dict()
            if hasattr(self.tab_list, 'to_alipay_dict'):
                params['tab_list'] = self.tab_list.to_alipay_dict()
            else:
                params['tab_list'] = self.tab_list
        if self.update_user:
            if hasattr(self.update_user, 'to_alipay_dict'):
                params['update_user'] = self.update_user.to_alipay_dict()
            else:
                params['update_user'] = self.update_user
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbdishAreaInfo()
        if 'area_free_list' in d:
            o.area_free_list = d['area_free_list']
        if 'area_id' in d:
            o.area_id = d['area_id']
        if 'area_name' in d:
            o.area_name = d['area_name']
        if 'area_sort' in d:
            o.area_sort = d['area_sort']
        if 'create_user' in d:
            o.create_user = d['create_user']
        if 'fee_price' in d:
            o.fee_price = d['fee_price']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'status' in d:
            o.status = d['status']
        if 'tab_count' in d:
            o.tab_count = d['tab_count']
        if 'tab_list' in d:
            o.tab_list = d['tab_list']
        if 'update_user' in d:
            o.update_user = d['update_user']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AccountCloseBusinessParams import AccountCloseBusinessParams


class AlipayFundAccountbookCloseModel(object):

    def __init__(self):
        self._account_book_id = None
        self._business_params = None
        self._scene_code = None

    @property
    def account_book_id(self):
        return self._account_book_id

    @account_book_id.setter
    def account_book_id(self, value):
        self._account_book_id = value
    @property
    def business_params(self):
        return self._business_params

    @business_params.setter
    def business_params(self, value):
        if isinstance(value, AccountCloseBusinessParams):
            self._business_params = value
        else:
            self._business_params = AccountCloseBusinessParams.from_alipay_dict(value)
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_book_id:
            if hasattr(self.account_book_id, 'to_alipay_dict'):
                params['account_book_id'] = self.account_book_id.to_alipay_dict()
            else:
                params['account_book_id'] = self.account_book_id
        if self.business_params:
            if hasattr(self.business_params, 'to_alipay_dict'):
                params['business_params'] = self.business_params.to_alipay_dict()
            else:
                params['business_params'] = self.business_params
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundAccountbookCloseModel()
        if 'account_book_id' in d:
            o.account_book_id = d['account_book_id']
        if 'business_params' in d:
            o.business_params = d['business_params']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class DatadigitalFincloudFinsaasPutplanCreateResponse(AlipayResponse):

    def __init__(self):
        super(DatadigitalFincloudFinsaasPutplanCreateResponse, self).__init__()
        self._put_plan_id = None

    @property
    def put_plan_id(self):
        return self._put_plan_id

    @put_plan_id.setter
    def put_plan_id(self, value):
        self._put_plan_id = value

    def parse_response_content(self, response_content):
        response = super(DatadigitalFincloudFinsaasPutplanCreateResponse, self).parse_response_content(response_content)
        if 'put_plan_id' in response:
            self.put_plan_id = response['put_plan_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AntProdpaasTttDetectResponse(AlipayResponse):

    def __init__(self):
        super(AntProdpaasTttDetectResponse, self).__init__()
        self._mobile = None
        self._oo = None

    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def oo(self):
        return self._oo

    @oo.setter
    def oo(self, value):
        self._oo = value

    def parse_response_content(self, response_content):
        response = super(AntProdpaasTttDetectResponse, self).parse_response_content(response_content)
        if 'mobile' in response:
            self.mobile = response['mobile']
        if 'oo' in response:
            self.oo = response['oo']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.LightPosOrderSku import LightPosOrderSku


class AlipayOpenIotmbsOrderprintreceiptQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenIotmbsOrderprintreceiptQueryResponse, self).__init__()
        self._pay_channel = None
        self._pay_time = None
        self._price = None
        self._real_price = None
        self._sku_list = None
        self._status = None

    @property
    def pay_channel(self):
        return self._pay_channel

    @pay_channel.setter
    def pay_channel(self, value):
        self._pay_channel = value
    @property
    def pay_time(self):
        return self._pay_time

    @pay_time.setter
    def pay_time(self, value):
        self._pay_time = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def real_price(self):
        return self._real_price

    @real_price.setter
    def real_price(self, value):
        self._real_price = value
    @property
    def sku_list(self):
        return self._sku_list

    @sku_list.setter
    def sku_list(self, value):
        if isinstance(value, list):
            self._sku_list = list()
            for i in value:
                if isinstance(i, LightPosOrderSku):
                    self._sku_list.append(i)
                else:
                    self._sku_list.append(LightPosOrderSku.from_alipay_dict(i))
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenIotmbsOrderprintreceiptQueryResponse, self).parse_response_content(response_content)
        if 'pay_channel' in response:
            self.pay_channel = response['pay_channel']
        if 'pay_time' in response:
            self.pay_time = response['pay_time']
        if 'price' in response:
            self.price = response['price']
        if 'real_price' in response:
            self.real_price = response['real_price']
        if 'sku_list' in response:
            self.sku_list = response['sku_list']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserSessionGetModel(object):

    def __init__(self):
        self._agent_app_id = None
        self._login_code = None

    @property
    def agent_app_id(self):
        return self._agent_app_id

    @agent_app_id.setter
    def agent_app_id(self, value):
        self._agent_app_id = value
    @property
    def login_code(self):
        return self._login_code

    @login_code.setter
    def login_code(self, value):
        self._login_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.agent_app_id:
            if hasattr(self.agent_app_id, 'to_alipay_dict'):
                params['agent_app_id'] = self.agent_app_id.to_alipay_dict()
            else:
                params['agent_app_id'] = self.agent_app_id
        if self.login_code:
            if hasattr(self.login_code, 'to_alipay_dict'):
                params['login_code'] = self.login_code.to_alipay_dict()
            else:
                params['login_code'] = self.login_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserSessionGetModel()
        if 'agent_app_id' in d:
            o.agent_app_id = d['agent_app_id']
        if 'login_code' in d:
            o.login_code = d['login_code']
        return o


